# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
TopOpeBRepBuild module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_topopebrepbuild.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _TopOpeBRepBuild
else:
    import _TopOpeBRepBuild

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _TopOpeBRepBuild.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _TopOpeBRepBuild.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _TopOpeBRepBuild.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _TopOpeBRepBuild.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _TopOpeBRepBuild.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _TopOpeBRepBuild.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _TopOpeBRepBuild.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _TopOpeBRepBuild.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _TopOpeBRepBuild.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _TopOpeBRepBuild.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _TopOpeBRepBuild.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _TopOpeBRepBuild.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _TopOpeBRepBuild.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _TopOpeBRepBuild.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _TopOpeBRepBuild.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _TopOpeBRepBuild.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _TopOpeBRepBuild.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _TopOpeBRepBuild:
_TopOpeBRepBuild.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _TopOpeBRepBuild.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.TopOpeBRepDS
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.TopOpeBRepTool
import OCC.Core.BRepClass3d
import OCC.Core.IntCurveSurface
import OCC.Core.math
import OCC.Core.Adaptor3d
import OCC.Core.Adaptor2d
import OCC.Core.Geom2d
import OCC.Core.Intf
import OCC.Core.Bnd
import OCC.Core.BVH
import OCC.Core.IntSurf
import OCC.Core.TopTools
import OCC.Core.IntCurvesFace
import OCC.Core.BRepAdaptor
import OCC.Core.GeomAdaptor
import OCC.Core.Geom2dAdaptor
import OCC.Core.TopExp
import OCC.Core.Extrema

from enum import IntEnum
from OCC.Core.Exception import *

TopOpeBRepBuild_ANYLOOP = _TopOpeBRepBuild.TopOpeBRepBuild_ANYLOOP
TopOpeBRepBuild_BOUNDARY = _TopOpeBRepBuild.TopOpeBRepBuild_BOUNDARY
TopOpeBRepBuild_BLOCK = _TopOpeBRepBuild.TopOpeBRepBuild_BLOCK


class TopOpeBRepBuild_LoopEnum(IntEnum):
	TopOpeBRepBuild_ANYLOOP = 0
	TopOpeBRepBuild_BOUNDARY = 1
	TopOpeBRepBuild_BLOCK = 2
TopOpeBRepBuild_ANYLOOP = TopOpeBRepBuild_LoopEnum.TopOpeBRepBuild_ANYLOOP
TopOpeBRepBuild_BOUNDARY = TopOpeBRepBuild_LoopEnum.TopOpeBRepBuild_BOUNDARY
TopOpeBRepBuild_BLOCK = TopOpeBRepBuild_LoopEnum.TopOpeBRepBuild_BLOCK


def Handle_TopOpeBRepBuild_HBuilder_Create() -> "opencascade::handle< TopOpeBRepBuild_HBuilder >":
    return _TopOpeBRepBuild.Handle_TopOpeBRepBuild_HBuilder_Create()

def Handle_TopOpeBRepBuild_HBuilder_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TopOpeBRepBuild_HBuilder >":
    return _TopOpeBRepBuild.Handle_TopOpeBRepBuild_HBuilder_DownCast(t)

def Handle_TopOpeBRepBuild_HBuilder_IsNull(t: "opencascade::handle< TopOpeBRepBuild_HBuilder > const &") -> "bool":
    return _TopOpeBRepBuild.Handle_TopOpeBRepBuild_HBuilder_IsNull(t)

def Handle_TopOpeBRepBuild_Loop_Create() -> "opencascade::handle< TopOpeBRepBuild_Loop >":
    return _TopOpeBRepBuild.Handle_TopOpeBRepBuild_Loop_Create()

def Handle_TopOpeBRepBuild_Loop_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TopOpeBRepBuild_Loop >":
    return _TopOpeBRepBuild.Handle_TopOpeBRepBuild_Loop_DownCast(t)

def Handle_TopOpeBRepBuild_Loop_IsNull(t: "opencascade::handle< TopOpeBRepBuild_Loop > const &") -> "bool":
    return _TopOpeBRepBuild.Handle_TopOpeBRepBuild_Loop_IsNull(t)

def Handle_TopOpeBRepBuild_Pave_Create() -> "opencascade::handle< TopOpeBRepBuild_Pave >":
    return _TopOpeBRepBuild.Handle_TopOpeBRepBuild_Pave_Create()

def Handle_TopOpeBRepBuild_Pave_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TopOpeBRepBuild_Pave >":
    return _TopOpeBRepBuild.Handle_TopOpeBRepBuild_Pave_DownCast(t)

def Handle_TopOpeBRepBuild_Pave_IsNull(t: "opencascade::handle< TopOpeBRepBuild_Pave > const &") -> "bool":
    return _TopOpeBRepBuild.Handle_TopOpeBRepBuild_Pave_IsNull(t)
class TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_DataMap< TopoDS_Shape,TopOpeBRepBuild_ListOfShapeListOfShape,TopTools_ShapeMapHasher >::iterator":
        return _TopOpeBRepBuild.TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape_begin(self)

    def end(self) -> "NCollection_DataMap< TopoDS_Shape,TopOpeBRepBuild_ListOfShapeListOfShape,TopTools_ShapeMapHasher >::iterator":
        return _TopOpeBRepBuild.TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape_end(self)

    def cbegin(self) -> "NCollection_DataMap< TopoDS_Shape,TopOpeBRepBuild_ListOfShapeListOfShape,TopTools_ShapeMapHasher >::const_iterator":
        return _TopOpeBRepBuild.TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape_cbegin(self)

    def cend(self) -> "NCollection_DataMap< TopoDS_Shape,TopOpeBRepBuild_ListOfShapeListOfShape,TopTools_ShapeMapHasher >::const_iterator":
        return _TopOpeBRepBuild.TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape_cend(self)

    def __init__(self, *args):
        _TopOpeBRepBuild.TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape(*args))

    def Exchange(self, theOther: "TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape") -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape_Exchange(self, theOther)

    def Assign(self, theOther: "TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape") -> "NCollection_DataMap< TopoDS_Shape,TopOpeBRepBuild_ListOfShapeListOfShape,TopTools_ShapeMapHasher > &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape_Assign(self, theOther)

    def Set(self, theOther: "TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape") -> "NCollection_DataMap< TopoDS_Shape,TopOpeBRepBuild_ListOfShapeListOfShape,TopTools_ShapeMapHasher > &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape_Set(self, theOther)

    def ReSize(self, N: "Standard_Integer const") -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape_ReSize(self, N)

    def Bind(self, theKey: "TopoDS_Shape", theItem: "TopOpeBRepBuild_ListOfShapeListOfShape") -> "Standard_Boolean":
        return _TopOpeBRepBuild.TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape_Bind(self, theKey, theItem)

    def Bound(self, theKey: "TopoDS_Shape", theItem: "TopOpeBRepBuild_ListOfShapeListOfShape") -> "TopOpeBRepBuild_ListOfShapeListOfShape *":
        return _TopOpeBRepBuild.TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape_Bound(self, theKey, theItem)

    def IsBound(self, theKey: "TopoDS_Shape") -> "Standard_Boolean":
        return _TopOpeBRepBuild.TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape_IsBound(self, theKey)

    def UnBind(self, theKey: "TopoDS_Shape") -> "Standard_Boolean":
        return _TopOpeBRepBuild.TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape_UnBind(self, theKey)

    def Seek(self, theKey: "TopoDS_Shape") -> "TopOpeBRepBuild_ListOfShapeListOfShape const *":
        return _TopOpeBRepBuild.TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape_Seek(self, theKey)

    def Find(self, *args) -> "Standard_Boolean":
        return _TopOpeBRepBuild.TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape_Find(self, *args)

    def ChangeSeek(self, theKey: "TopoDS_Shape") -> "TopOpeBRepBuild_ListOfShapeListOfShape *":
        return _TopOpeBRepBuild.TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape_ChangeSeek(self, theKey)

    def ChangeFind(self, theKey: "TopoDS_Shape") -> "TopOpeBRepBuild_ListOfShapeListOfShape &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape_ChangeFind(self, theKey)

    def __call__(self, *args) -> "TopOpeBRepBuild_ListOfShapeListOfShape &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape___call__(self, *args)

    def Clear(self, *args) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape_Clear(self, *args)
    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape

    def Size(self) -> "Standard_Integer":
        return _TopOpeBRepBuild.TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape_Size(self)

# Register TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape_swigregister(TopOpeBRepBuild_DataMapOfShapeListOfShapeListOfShape)

class TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_IndexedDataMap< TopoDS_Shape,TopOpeBRepBuild_VertexInfo,TopTools_ShapeMapHasher >::iterator":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_begin(self)

    def end(self) -> "NCollection_IndexedDataMap< TopoDS_Shape,TopOpeBRepBuild_VertexInfo,TopTools_ShapeMapHasher >::iterator":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_end(self)

    def cbegin(self) -> "NCollection_IndexedDataMap< TopoDS_Shape,TopOpeBRepBuild_VertexInfo,TopTools_ShapeMapHasher >::const_iterator":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_cbegin(self)

    def cend(self) -> "NCollection_IndexedDataMap< TopoDS_Shape,TopOpeBRepBuild_VertexInfo,TopTools_ShapeMapHasher >::const_iterator":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_cend(self)

    def __init__(self, *args):
        _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo(*args))

    def Exchange(self, theOther: "TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo") -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_Exchange(self, theOther)

    def Assign(self, theOther: "TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo") -> "NCollection_IndexedDataMap< TopoDS_Shape,TopOpeBRepBuild_VertexInfo,TopTools_ShapeMapHasher > &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_Assign(self, theOther)

    def Set(self, theOther: "TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo") -> "NCollection_IndexedDataMap< TopoDS_Shape,TopOpeBRepBuild_VertexInfo,TopTools_ShapeMapHasher > &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_Set(self, theOther)

    def ReSize(self, N: "Standard_Integer const") -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_ReSize(self, N)

    def Add(self, theKey1: "TopoDS_Shape", theItem: "TopOpeBRepBuild_VertexInfo") -> "Standard_Integer":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_Add(self, theKey1, theItem)

    def Contains(self, theKey1: "TopoDS_Shape") -> "Standard_Boolean":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_Contains(self, theKey1)

    def Substitute(self, theIndex: "Standard_Integer const", theKey1: "TopoDS_Shape", theItem: "TopOpeBRepBuild_VertexInfo") -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_Substitute(self, theIndex, theKey1, theItem)

    def Swap(self, theIndex1: "Standard_Integer const", theIndex2: "Standard_Integer const") -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_Swap(self, theIndex1, theIndex2)

    def RemoveLast(self) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_RemoveLast(self)

    def RemoveFromIndex(self, theIndex: "Standard_Integer const") -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_RemoveFromIndex(self, theIndex)

    def RemoveKey(self, theKey1: "TopoDS_Shape") -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_RemoveKey(self, theKey1)

    def FindKey(self, theIndex: "Standard_Integer const") -> "TopoDS_Shape const &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_FindKey(self, theIndex)

    def FindFromIndex(self, theIndex: "Standard_Integer const") -> "TopOpeBRepBuild_VertexInfo const &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_FindFromIndex(self, theIndex)

    def ChangeFromIndex(self, theIndex: "Standard_Integer const") -> "TopOpeBRepBuild_VertexInfo &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_ChangeFromIndex(self, theIndex)

    def __call__(self, *args) -> "TopOpeBRepBuild_VertexInfo &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo___call__(self, *args)

    def FindIndex(self, theKey1: "TopoDS_Shape") -> "Standard_Integer":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_FindIndex(self, theKey1)

    def ChangeFromKey(self, theKey1: "TopoDS_Shape") -> "TopOpeBRepBuild_VertexInfo &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_ChangeFromKey(self, theKey1)

    def Seek(self, theKey1: "TopoDS_Shape") -> "TopOpeBRepBuild_VertexInfo const *":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_Seek(self, theKey1)

    def ChangeSeek(self, theKey1: "TopoDS_Shape") -> "TopOpeBRepBuild_VertexInfo *":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_ChangeSeek(self, theKey1)

    def FindFromKey(self, *args) -> "Standard_Boolean":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_FindFromKey(self, *args)

    def Clear(self, *args) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_Clear(self, *args)
    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo

    def Size(self) -> "Standard_Integer":
        return _TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_Size(self)

# Register TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo_swigregister(TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo)

class TopOpeBRepBuild_ListIteratorOfListOfListOfLoop(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TopOpeBRepBuild.TopOpeBRepBuild_ListIteratorOfListOfListOfLoop_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_ListIteratorOfListOfListOfLoop(*args))

    def More(self) -> "Standard_Boolean":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListIteratorOfListOfListOfLoop_More(self)

    def Next(self) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListIteratorOfListOfListOfLoop_Next(self)

    def Value(self) -> "TopOpeBRepBuild_ListOfLoop const &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListIteratorOfListOfListOfLoop_Value(self)

    def ChangeValue(self) -> "TopOpeBRepBuild_ListOfLoop &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListIteratorOfListOfListOfLoop_ChangeValue(self)
    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_ListIteratorOfListOfListOfLoop

# Register TopOpeBRepBuild_ListIteratorOfListOfListOfLoop in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_ListIteratorOfListOfListOfLoop_swigregister(TopOpeBRepBuild_ListIteratorOfListOfListOfLoop)

class TopOpeBRepBuild_ListIteratorOfListOfLoop(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TopOpeBRepBuild.TopOpeBRepBuild_ListIteratorOfListOfLoop_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_ListIteratorOfListOfLoop(*args))

    def More(self) -> "Standard_Boolean":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListIteratorOfListOfLoop_More(self)

    def Next(self) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListIteratorOfListOfLoop_Next(self)

    def Value(self) -> "opencascade::handle< TopOpeBRepBuild_Loop > const &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListIteratorOfListOfLoop_Value(self)

    def ChangeValue(self) -> "opencascade::handle< TopOpeBRepBuild_Loop > &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListIteratorOfListOfLoop_ChangeValue(self)
    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_ListIteratorOfListOfLoop

# Register TopOpeBRepBuild_ListIteratorOfListOfLoop in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_ListIteratorOfListOfLoop_swigregister(TopOpeBRepBuild_ListIteratorOfListOfLoop)

class TopOpeBRepBuild_ListIteratorOfListOfPave(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TopOpeBRepBuild.TopOpeBRepBuild_ListIteratorOfListOfPave_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_ListIteratorOfListOfPave(*args))

    def More(self) -> "Standard_Boolean":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListIteratorOfListOfPave_More(self)

    def Next(self) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListIteratorOfListOfPave_Next(self)

    def Value(self) -> "opencascade::handle< TopOpeBRepBuild_Pave > const &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListIteratorOfListOfPave_Value(self)

    def ChangeValue(self) -> "opencascade::handle< TopOpeBRepBuild_Pave > &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListIteratorOfListOfPave_ChangeValue(self)
    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_ListIteratorOfListOfPave

# Register TopOpeBRepBuild_ListIteratorOfListOfPave in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_ListIteratorOfListOfPave_swigregister(TopOpeBRepBuild_ListIteratorOfListOfPave)

class TopOpeBRepBuild_ListIteratorOfListOfShapeListOfShape(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TopOpeBRepBuild.TopOpeBRepBuild_ListIteratorOfListOfShapeListOfShape_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_ListIteratorOfListOfShapeListOfShape(*args))

    def More(self) -> "Standard_Boolean":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListIteratorOfListOfShapeListOfShape_More(self)

    def Next(self) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListIteratorOfListOfShapeListOfShape_Next(self)

    def Value(self) -> "TopOpeBRepBuild_ShapeListOfShape const &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListIteratorOfListOfShapeListOfShape_Value(self)

    def ChangeValue(self) -> "TopOpeBRepBuild_ShapeListOfShape &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListIteratorOfListOfShapeListOfShape_ChangeValue(self)
    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_ListIteratorOfListOfShapeListOfShape

# Register TopOpeBRepBuild_ListIteratorOfListOfShapeListOfShape in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_ListIteratorOfListOfShapeListOfShape_swigregister(TopOpeBRepBuild_ListIteratorOfListOfShapeListOfShape)

class TopOpeBRepBuild_ListOfListOfLoop(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_List< TopOpeBRepBuild_ListOfLoop >::iterator":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfListOfLoop_begin(self)

    def end(self) -> "NCollection_List< TopOpeBRepBuild_ListOfLoop >::iterator":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfListOfLoop_end(self)

    def cbegin(self) -> "NCollection_List< TopOpeBRepBuild_ListOfLoop >::const_iterator":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfListOfLoop_cbegin(self)

    def cend(self) -> "NCollection_List< TopOpeBRepBuild_ListOfLoop >::const_iterator":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfListOfLoop_cend(self)

    def __init__(self, *args):
        _TopOpeBRepBuild.TopOpeBRepBuild_ListOfListOfLoop_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_ListOfListOfLoop(*args))

    def Size(self) -> "Standard_Integer":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfListOfLoop_Size(self)

    def Assign(self, theOther: "TopOpeBRepBuild_ListOfListOfLoop") -> "NCollection_List< TopOpeBRepBuild_ListOfLoop > &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfListOfLoop_Assign(self, theOther)

    def Set(self, theOther: "TopOpeBRepBuild_ListOfListOfLoop") -> "NCollection_List< TopOpeBRepBuild_ListOfLoop > &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfListOfLoop_Set(self, theOther)

    def Clear(self, theAllocator: "IntSurf_Allocator"=0) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfListOfLoop_Clear(self, theAllocator)

    def First(self) -> "TopOpeBRepBuild_ListOfLoop const &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfListOfLoop_First(self)

    def Last(self) -> "TopOpeBRepBuild_ListOfLoop const &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfListOfLoop_Last(self)

    def Append(self, *args) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfListOfLoop_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfListOfLoop_Prepend(self, *args)

    def RemoveFirst(self) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfListOfLoop_RemoveFirst(self)

    def Remove(self, theIter: "NCollection_List< TopOpeBRepBuild_ListOfLoop >::Iterator &") -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfListOfLoop_Remove(self, theIter)

    def InsertBefore(self, *args) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfListOfLoop_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfListOfLoop_InsertAfter(self, *args)

    def Reverse(self) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfListOfLoop_Reverse(self)
    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_ListOfListOfLoop

    def __len__(self):
        return self.Size()


# Register TopOpeBRepBuild_ListOfListOfLoop in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_ListOfListOfLoop_swigregister(TopOpeBRepBuild_ListOfListOfLoop)

class TopOpeBRepBuild_ListOfLoop(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_List< opencascade::handle< TopOpeBRepBuild_Loop > >::iterator":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfLoop_begin(self)

    def end(self) -> "NCollection_List< opencascade::handle< TopOpeBRepBuild_Loop > >::iterator":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfLoop_end(self)

    def cbegin(self) -> "NCollection_List< opencascade::handle< TopOpeBRepBuild_Loop > >::const_iterator":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfLoop_cbegin(self)

    def cend(self) -> "NCollection_List< opencascade::handle< TopOpeBRepBuild_Loop > >::const_iterator":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfLoop_cend(self)

    def __init__(self, *args):
        _TopOpeBRepBuild.TopOpeBRepBuild_ListOfLoop_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_ListOfLoop(*args))

    def Size(self) -> "Standard_Integer":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfLoop_Size(self)

    def Assign(self, theOther: "TopOpeBRepBuild_ListOfLoop") -> "NCollection_List< opencascade::handle< TopOpeBRepBuild_Loop > > &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfLoop_Assign(self, theOther)

    def Set(self, theOther: "TopOpeBRepBuild_ListOfLoop") -> "NCollection_List< opencascade::handle< TopOpeBRepBuild_Loop > > &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfLoop_Set(self, theOther)

    def Clear(self, theAllocator: "IntSurf_Allocator"=0) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfLoop_Clear(self, theAllocator)

    def First(self) -> "opencascade::handle< TopOpeBRepBuild_Loop > const &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfLoop_First(self)

    def Last(self) -> "opencascade::handle< TopOpeBRepBuild_Loop > const &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfLoop_Last(self)

    def Append(self, *args) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfLoop_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfLoop_Prepend(self, *args)

    def RemoveFirst(self) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfLoop_RemoveFirst(self)

    def Remove(self, theIter: "TopOpeBRepBuild_ListIteratorOfListOfLoop") -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfLoop_Remove(self, theIter)

    def InsertBefore(self, *args) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfLoop_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfLoop_InsertAfter(self, *args)

    def Reverse(self) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfLoop_Reverse(self)
    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_ListOfLoop

    def __len__(self):
        return self.Size()


# Register TopOpeBRepBuild_ListOfLoop in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_ListOfLoop_swigregister(TopOpeBRepBuild_ListOfLoop)

class TopOpeBRepBuild_ListOfPave(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_List< opencascade::handle< TopOpeBRepBuild_Pave > >::iterator":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfPave_begin(self)

    def end(self) -> "NCollection_List< opencascade::handle< TopOpeBRepBuild_Pave > >::iterator":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfPave_end(self)

    def cbegin(self) -> "NCollection_List< opencascade::handle< TopOpeBRepBuild_Pave > >::const_iterator":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfPave_cbegin(self)

    def cend(self) -> "NCollection_List< opencascade::handle< TopOpeBRepBuild_Pave > >::const_iterator":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfPave_cend(self)

    def __init__(self, *args):
        _TopOpeBRepBuild.TopOpeBRepBuild_ListOfPave_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_ListOfPave(*args))

    def Size(self) -> "Standard_Integer":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfPave_Size(self)

    def Assign(self, theOther: "TopOpeBRepBuild_ListOfPave") -> "NCollection_List< opencascade::handle< TopOpeBRepBuild_Pave > > &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfPave_Assign(self, theOther)

    def Set(self, theOther: "TopOpeBRepBuild_ListOfPave") -> "NCollection_List< opencascade::handle< TopOpeBRepBuild_Pave > > &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfPave_Set(self, theOther)

    def Clear(self, theAllocator: "IntSurf_Allocator"=0) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfPave_Clear(self, theAllocator)

    def First(self) -> "opencascade::handle< TopOpeBRepBuild_Pave > const &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfPave_First(self)

    def Last(self) -> "opencascade::handle< TopOpeBRepBuild_Pave > const &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfPave_Last(self)

    def Append(self, *args) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfPave_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfPave_Prepend(self, *args)

    def RemoveFirst(self) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfPave_RemoveFirst(self)

    def Remove(self, theIter: "TopOpeBRepBuild_ListIteratorOfListOfPave") -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfPave_Remove(self, theIter)

    def InsertBefore(self, *args) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfPave_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfPave_InsertAfter(self, *args)

    def Reverse(self) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfPave_Reverse(self)
    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_ListOfPave

    def __len__(self):
        return self.Size()


# Register TopOpeBRepBuild_ListOfPave in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_ListOfPave_swigregister(TopOpeBRepBuild_ListOfPave)

class TopOpeBRepBuild_ListOfShapeListOfShape(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_List< TopOpeBRepBuild_ShapeListOfShape >::iterator":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfShapeListOfShape_begin(self)

    def end(self) -> "NCollection_List< TopOpeBRepBuild_ShapeListOfShape >::iterator":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfShapeListOfShape_end(self)

    def cbegin(self) -> "NCollection_List< TopOpeBRepBuild_ShapeListOfShape >::const_iterator":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfShapeListOfShape_cbegin(self)

    def cend(self) -> "NCollection_List< TopOpeBRepBuild_ShapeListOfShape >::const_iterator":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfShapeListOfShape_cend(self)

    def __init__(self, *args):
        _TopOpeBRepBuild.TopOpeBRepBuild_ListOfShapeListOfShape_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_ListOfShapeListOfShape(*args))

    def Size(self) -> "Standard_Integer":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfShapeListOfShape_Size(self)

    def Assign(self, theOther: "TopOpeBRepBuild_ListOfShapeListOfShape") -> "NCollection_List< TopOpeBRepBuild_ShapeListOfShape > &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfShapeListOfShape_Assign(self, theOther)

    def Set(self, theOther: "TopOpeBRepBuild_ListOfShapeListOfShape") -> "NCollection_List< TopOpeBRepBuild_ShapeListOfShape > &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfShapeListOfShape_Set(self, theOther)

    def Clear(self, theAllocator: "IntSurf_Allocator"=0) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfShapeListOfShape_Clear(self, theAllocator)

    def First(self) -> "TopOpeBRepBuild_ShapeListOfShape const &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfShapeListOfShape_First(self)

    def Last(self) -> "TopOpeBRepBuild_ShapeListOfShape const &":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfShapeListOfShape_Last(self)

    def Append(self, *args) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfShapeListOfShape_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfShapeListOfShape_Prepend(self, *args)

    def RemoveFirst(self) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfShapeListOfShape_RemoveFirst(self)

    def Remove(self, theIter: "TopOpeBRepBuild_ListIteratorOfListOfShapeListOfShape") -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfShapeListOfShape_Remove(self, theIter)

    def InsertBefore(self, *args) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfShapeListOfShape_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfShapeListOfShape_InsertAfter(self, *args)

    def Reverse(self) -> "void":
        return _TopOpeBRepBuild.TopOpeBRepBuild_ListOfShapeListOfShape_Reverse(self)
    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_ListOfShapeListOfShape

    def __len__(self):
        return self.Size()


# Register TopOpeBRepBuild_ListOfShapeListOfShape in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_ListOfShapeListOfShape_swigregister(TopOpeBRepBuild_ListOfShapeListOfShape)

class TopOpeBRepBuild_AreaBuilder(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        Creates a areabuilder to build the areas on the shapes described by <ls> using the classifier <lc>.

        Parameters
        ----------
        LS: TopOpeBRepBuild_LoopSet
        LC: TopOpeBRepBuild_LoopClassifier
        ForceClass: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_AreaBuilder_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_AreaBuilder(*args))

    def ADD_LISTOFLoop_TO_LISTOFLoop(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        LOL1: TopOpeBRepBuild_ListOfLoop
        LOL2: TopOpeBRepBuild_ListOfLoop
        s: Standard_Address,optional
        	default value is NULL
        s1: Standard_Address,optional
        	default value is NULL
        s2: Standard_Address,optional
        	default value is NULL

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_AreaBuilder_ADD_LISTOFLoop_TO_LISTOFLoop(self, *args)

    def ADD_Loop_TO_LISTOFLoop(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        L: TopOpeBRepBuild_Loop
        LOL: TopOpeBRepBuild_ListOfLoop
        s: Standard_Address,optional
        	default value is NULL

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_AreaBuilder_ADD_Loop_TO_LISTOFLoop(self, *args)

    def InitArea(self, *args) -> "Standard_Integer":
        r"""
        Initialize iteration on areas.

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_AreaBuilder_InitArea(self, *args)

    def InitAreaBuilder(self, *args) -> "void":
        r"""
        Sets a areabuilder to find the areas on the shapes described by <ls> using the classifier <lc>.

        Parameters
        ----------
        LS: TopOpeBRepBuild_LoopSet
        LC: TopOpeBRepBuild_LoopClassifier
        ForceClass: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_AreaBuilder_InitAreaBuilder(self, *args)

    def InitLoop(self, *args) -> "Standard_Integer":
        r"""
        Initialize iteration on loops of current area.

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_AreaBuilder_InitLoop(self, *args)

    def Loop(self, *args) -> "opencascade::handle< TopOpeBRepBuild_Loop > const &":
        r"""
        Returns the current loop in the current area.

        Returns
        -------
        opencascade::handle<TopOpeBRepBuild_Loop>

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_AreaBuilder_Loop(self, *args)

    def MoreArea(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_AreaBuilder_MoreArea(self, *args)

    def MoreLoop(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_AreaBuilder_MoreLoop(self, *args)

    def NextArea(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_AreaBuilder_NextArea(self, *args)

    def NextLoop(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_AreaBuilder_NextLoop(self, *args)

    def REM_Loop_FROM_LISTOFLoop(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ITLOL: TopOpeBRepBuild_ListIteratorOfListOfLoop
        LOL: TopOpeBRepBuild_ListOfLoop
        s: Standard_Address,optional
        	default value is NULL

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_AreaBuilder_REM_Loop_FROM_LISTOFLoop(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_AreaBuilder

# Register TopOpeBRepBuild_AreaBuilder in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_AreaBuilder_swigregister(TopOpeBRepBuild_AreaBuilder)

class TopOpeBRepBuild_BlockBuilder(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        SS: TopOpeBRepBuild_ShapeSet

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_BlockBuilder_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_BlockBuilder(*args))

    def AddElement(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_BlockBuilder_AddElement(self, *args)

    def BlockIterator(self, *args) -> "TopOpeBRepBuild_BlockIterator":
        r"""
        No available documentation.

        Returns
        -------
        TopOpeBRepBuild_BlockIterator

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_BlockBuilder_BlockIterator(self, *args)

    def CurrentBlockIsRegular(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_BlockBuilder_CurrentBlockIsRegular(self, *args)

    def Element(self, *args) -> "Standard_Integer":
        r"""
        Returns the current element of <bi>.

        Parameters
        ----------
        BI: TopOpeBRepBuild_BlockIterator

        Returns
        -------
        TopoDS_Shape
        No available documentation.

        Parameters
        ----------
        I: int

        Returns
        -------
        TopoDS_Shape
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_BlockBuilder_Element(self, *args)

    def ElementIsValid(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        BI: TopOpeBRepBuild_BlockIterator

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        I: int

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_BlockBuilder_ElementIsValid(self, *args)

    def InitBlock(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_BlockBuilder_InitBlock(self, *args)

    def MakeBlock(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SS: TopOpeBRepBuild_ShapeSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_BlockBuilder_MakeBlock(self, *args)

    def MoreBlock(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_BlockBuilder_MoreBlock(self, *args)

    def NextBlock(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_BlockBuilder_NextBlock(self, *args)

    def SetValid(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        BI: TopOpeBRepBuild_BlockIterator
        isvalid: bool

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        I: int
        isvalid: bool

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_BlockBuilder_SetValid(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_BlockBuilder

# Register TopOpeBRepBuild_BlockBuilder in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_BlockBuilder_swigregister(TopOpeBRepBuild_BlockBuilder)

class TopOpeBRepBuild_BlockIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Lower: int
        Upper: int

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_BlockIterator_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_BlockIterator(*args))

    def Extent(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_BlockIterator_Extent(self, *args)

    def Initialize(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_BlockIterator_Initialize(self, *args)

    def More(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_BlockIterator_More(self, *args)

    def Next(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_BlockIterator_Next(self, *args)

    def Value(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_BlockIterator_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_BlockIterator

# Register TopOpeBRepBuild_BlockIterator in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_BlockIterator_swigregister(TopOpeBRepBuild_BlockIterator)

class TopOpeBRepBuild_Builder(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        BT: TopOpeBRepDS_BuildTool

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_Builder_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_Builder(*args))

    def AddONPatchesSFS(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        G: TopOpeBRepBuild_GTopo
        SFS: TopOpeBRepBuild_ShellFaceSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_AddONPatchesSFS(self, *args)

    def BuildEdges(self, *args) -> "void":
        r"""
        Update the ds by creating new geometries. create shapes from the new geometries.

        Parameters
        ----------
        DS: TopOpeBRepDS_HDataStructure

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_BuildEdges(self, *args)

    def BuildTool(self, *args) -> "TopOpeBRepDS_BuildTool const &":
        r"""
        No available documentation.

        Returns
        -------
        TopOpeBRepDS_BuildTool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_BuildTool(self, *args)

    def BuildVertices(self, *args) -> "void":
        r"""
        Update the ds by creating new geometries. create vertices on ds points.

        Parameters
        ----------
        DS: TopOpeBRepDS_HDataStructure

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_BuildVertices(self, *args)

    def ChangeBuildTool(self, *args) -> "TopOpeBRepDS_BuildTool &":
        r"""
        No available documentation.

        Returns
        -------
        TopOpeBRepDS_BuildTool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_ChangeBuildTool(self, *args)

    def ChangeClassify(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        B: bool

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_ChangeClassify(self, *args)

    def ChangeMSplit(self, *args) -> "TopOpeBRepDS_DataMapOfShapeListOfShapeOn1State &":
        r"""
        No available documentation.

        Parameters
        ----------
        s: TopAbs_State

        Returns
        -------
        TopOpeBRepDS_DataMapOfShapeListOfShapeOn1State

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_ChangeMSplit(self, *args)

    def ChangeSplit(self, *args) -> "TopTools_ListOfShape &":
        r"""
        Returns a ref.on the list of shapes connected to <s> as <tb> split parts of <s>. mark <s> as split in <tb> parts.

        Parameters
        ----------
        S: TopoDS_Shape
        TB: TopAbs_State

        Returns
        -------
        TopTools_ListOfShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_ChangeSplit(self, *args)

    def Classify(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_Classify(self, *args)

    def Clear(self, *args) -> "void":
        r"""
        Removes all splits and merges already performed. does not clear the handled ds.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_Clear(self, *args)

    def ClearMaps(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_ClearMaps(self, *args)

    @staticmethod
    def Contains(*args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        L: TopTools_ListOfShape

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_Contains(*args)

    def DataStructure(self, *args) -> "opencascade::handle< TopOpeBRepDS_HDataStructure >":
        r"""
        Returns the ds handled by this builder.

        Returns
        -------
        opencascade::handle<TopOpeBRepDS_HDataStructure>

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_DataStructure(self, *args)

    def End(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_End(self, *args)

    def FillOnPatches(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        anEdgesON: TopTools_ListOfShape
        aBaseFace: TopoDS_Shape
        avoidMap: TopTools_IndexedMapOfOrientedShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_FillOnPatches(self, *args)

    def FillSecEdgeAncestorMap(self, *args) -> "void":
        r"""
        Fills anancmap with pairs (edge,ancestor edge) for each split from the map amapon for the shape object identified by shaperank.

        Parameters
        ----------
        aShapeRank: int
        aMapON: TopTools_MapOfShape
        anAncMap: TopTools_DataMapOfShapeShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_FillSecEdgeAncestorMap(self, *args)

    def FindFacesTouchingEdge(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aFace: TopoDS_Shape
        anEdge: TopoDS_Shape
        aShRank: int
        aFaces: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_FindFacesTouchingEdge(self, *args)

    def FindIsKPart(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_FindIsKPart(self, *args)

    def FindSameDomain(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        L1: TopTools_ListOfShape
        L2: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_FindSameDomain(self, *args)

    def FindSameDomainSameOrientation(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        LSO: TopTools_ListOfShape
        LDO: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_FindSameDomainSameOrientation(self, *args)

    def FindSameRank(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        L1: TopTools_ListOfShape
        R: int
        L2: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_FindSameRank(self, *args)

    def GClearMaps(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GClearMaps(self, *args)

    @staticmethod
    def GContains(*args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        L: TopTools_ListOfShape

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GContains(*args)

    @staticmethod
    def GCopyList(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Lin: TopTools_ListOfShape
        i1: int
        i2: int
        Lou: TopTools_ListOfShape

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Lin: TopTools_ListOfShape
        Lou: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GCopyList(*args)

    def GEDBUMakeEdges(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        EF: TopoDS_Shape
        EDBU: TopOpeBRepBuild_EdgeBuilder
        LOE: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GEDBUMakeEdges(self, *args)

    def GFABUMakeFaces(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        FF: TopoDS_Shape
        FABU: TopOpeBRepBuild_FaceBuilder
        LOF: TopTools_ListOfShape
        MWisOld: TopTools_DataMapOfShapeInteger

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GFABUMakeFaces(self, *args)

    def GFillCurveTopologyWES(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Shape
        G: TopOpeBRepBuild_GTopo
        WES: TopOpeBRepBuild_WireEdgeSet

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        IT: TopOpeBRepDS_CurveIterator
        G: TopOpeBRepBuild_GTopo
        WES: TopOpeBRepBuild_WireEdgeSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GFillCurveTopologyWES(self, *args)

    def GFillEdgePVS(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Shape
        LE2: TopTools_ListOfShape
        G: TopOpeBRepBuild_GTopo
        PVS: TopOpeBRepBuild_PaveSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GFillEdgePVS(self, *args)

    def GFillEdgeWES(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Shape
        LF2: TopTools_ListOfShape
        G: TopOpeBRepBuild_GTopo
        WES: TopOpeBRepBuild_WireEdgeSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GFillEdgeWES(self, *args)

    def GFillEdgesPVS(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        LE1: TopTools_ListOfShape
        LE2: TopTools_ListOfShape
        G: TopOpeBRepBuild_GTopo
        PVS: TopOpeBRepBuild_PaveSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GFillEdgesPVS(self, *args)

    def GFillFaceSFS(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        F1: TopoDS_Shape
        LSO2: TopTools_ListOfShape
        G: TopOpeBRepBuild_GTopo
        SFS: TopOpeBRepBuild_ShellFaceSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GFillFaceSFS(self, *args)

    def GFillFaceWES(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Shape
        LF2: TopTools_ListOfShape
        G: TopOpeBRepBuild_GTopo
        WES: TopOpeBRepBuild_WireEdgeSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GFillFaceWES(self, *args)

    def GFillFacesWES(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        LF1: TopTools_ListOfShape
        LF2: TopTools_ListOfShape
        G: TopOpeBRepBuild_GTopo
        WES: TopOpeBRepBuild_WireEdgeSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GFillFacesWES(self, *args)

    def GFillFacesWESK(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        LF1: TopTools_ListOfShape
        LF2: TopTools_ListOfShape
        G: TopOpeBRepBuild_GTopo
        WES: TopOpeBRepBuild_WireEdgeSet
        K: int

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GFillFacesWESK(self, *args)

    def GFillFacesWESMakeFaces(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        LF1: TopTools_ListOfShape
        LF2: TopTools_ListOfShape
        LSO: TopTools_ListOfShape
        G: TopOpeBRepBuild_GTopo

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GFillFacesWESMakeFaces(self, *args)

    def GFillONPartsWES(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Shape
        G: TopOpeBRepBuild_GTopo
        LSclass: TopTools_ListOfShape
        WES: TopOpeBRepBuild_WireEdgeSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GFillONPartsWES(self, *args)

    def GFillPointTopologyPVS(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Shape
        G: TopOpeBRepBuild_GTopo
        PVS: TopOpeBRepBuild_PaveSet

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Shape
        IT: TopOpeBRepDS_PointIterator
        G: TopOpeBRepBuild_GTopo
        PVS: TopOpeBRepBuild_PaveSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GFillPointTopologyPVS(self, *args)

    def GFillShellSFS(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SH1: TopoDS_Shape
        LSO2: TopTools_ListOfShape
        G: TopOpeBRepBuild_GTopo
        SFS: TopOpeBRepBuild_ShellFaceSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GFillShellSFS(self, *args)

    def GFillSolidSFS(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SO1: TopoDS_Shape
        LSO2: TopTools_ListOfShape
        G: TopOpeBRepBuild_GTopo
        SFS: TopOpeBRepBuild_ShellFaceSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GFillSolidSFS(self, *args)

    def GFillSolidsSFS(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        LSO1: TopTools_ListOfShape
        LSO2: TopTools_ListOfShape
        G: TopOpeBRepBuild_GTopo
        SFS: TopOpeBRepBuild_ShellFaceSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GFillSolidsSFS(self, *args)

    def GFillSurfaceTopologySFS(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SO1: TopoDS_Shape
        G: TopOpeBRepBuild_GTopo
        SFS: TopOpeBRepBuild_ShellFaceSet

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        IT: TopOpeBRepDS_SurfaceIterator
        G: TopOpeBRepBuild_GTopo
        SFS: TopOpeBRepBuild_ShellFaceSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GFillSurfaceTopologySFS(self, *args)

    def GFillWireWES(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        W: TopoDS_Shape
        LF2: TopTools_ListOfShape
        G: TopOpeBRepBuild_GTopo
        WES: TopOpeBRepBuild_WireEdgeSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GFillWireWES(self, *args)

    def GFindSamDom(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        L1: TopTools_ListOfShape
        L2: TopTools_ListOfShape

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        L1: TopTools_ListOfShape
        L2: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GFindSamDom(self, *args)

    def GFindSamDomSODO(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        LSO: TopTools_ListOfShape
        LDO: TopTools_ListOfShape

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        LSO: TopTools_ListOfShape
        LDO: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GFindSamDomSODO(self, *args)

    def GFindSameRank(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        L1: TopTools_ListOfShape
        R: int
        L2: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GFindSameRank(self, *args)

    def GIsShapeOf(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        I12: int

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GIsShapeOf(self, *args)

    def GKeepShape(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        Lref: TopTools_ListOfShape
        T: TopAbs_State

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GKeepShape(self, *args)

    def GKeepShape1(self, *args) -> "Standard_Boolean":
        r"""
        Return true if s is classified <t> / lref shapes.

        Parameters
        ----------
        S: TopoDS_Shape
        Lref: TopTools_ListOfShape
        T: TopAbs_State
        pos: TopAbs_State

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GKeepShape1(self, *args)

    def GKeepShapes(self, *args) -> "void":
        r"""
        Add to lou the shapes of lin classified <t> / lref shapes. lou is not cleared. (s is a dummy trace argument).

        Parameters
        ----------
        S: TopoDS_Shape
        Lref: TopTools_ListOfShape
        T: TopAbs_State
        Lin: TopTools_ListOfShape
        Lou: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GKeepShapes(self, *args)

    def GMapShapes(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        S1: TopoDS_Shape
        S2: TopoDS_Shape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GMapShapes(self, *args)

    def GMergeEdgeWES(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Shape
        G: TopOpeBRepBuild_GTopo
        WES: TopOpeBRepBuild_WireEdgeSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GMergeEdgeWES(self, *args)

    def GMergeEdges(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        LE1: TopTools_ListOfShape
        LE2: TopTools_ListOfShape
        G: TopOpeBRepBuild_GTopo

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GMergeEdges(self, *args)

    def GMergeFaceSFS(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Shape
        G: TopOpeBRepBuild_GTopo
        SFS: TopOpeBRepBuild_ShellFaceSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GMergeFaceSFS(self, *args)

    def GMergeFaces(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        LF1: TopTools_ListOfShape
        LF2: TopTools_ListOfShape
        G: TopOpeBRepBuild_GTopo

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GMergeFaces(self, *args)

    def GMergeSolids(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        LSO1: TopTools_ListOfShape
        LSO2: TopTools_ListOfShape
        G: TopOpeBRepBuild_GTopo

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GMergeSolids(self, *args)

    def GPVSMakeEdges(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        EF: TopoDS_Shape
        PVS: TopOpeBRepBuild_PaveSet
        LOE: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GPVSMakeEdges(self, *args)

    def GParamOnReference(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        V: TopoDS_Vertex
        E: TopoDS_Edge

        Returns
        -------
        P: float

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GParamOnReference(self, *args)

    def GSFSMakeSolids(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SOF: TopoDS_Shape
        SFS: TopOpeBRepBuild_ShellFaceSet
        LOSO: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GSFSMakeSolids(self, *args)

    def GSOBUMakeSolids(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SOF: TopoDS_Shape
        SOBU: TopOpeBRepBuild_SolidBuilder
        LOSO: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GSOBUMakeSolids(self, *args)

    def GShapeRank(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GShapeRank(self, *args)

    def GSplitEdge(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Shape
        G: TopOpeBRepBuild_GTopo
        LSclass: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GSplitEdge(self, *args)

    def GSplitEdgeWES(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Shape
        LF2: TopTools_ListOfShape
        G: TopOpeBRepBuild_GTopo
        WES: TopOpeBRepBuild_WireEdgeSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GSplitEdgeWES(self, *args)

    def GSplitFace(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Shape
        G: TopOpeBRepBuild_GTopo
        LSclass: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GSplitFace(self, *args)

    def GSplitFaceSFS(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        F1: TopoDS_Shape
        LSclass: TopTools_ListOfShape
        G: TopOpeBRepBuild_GTopo
        SFS: TopOpeBRepBuild_ShellFaceSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GSplitFaceSFS(self, *args)

    @staticmethod
    def GTakeCommonOfDiff(*args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        G: TopOpeBRepBuild_GTopo

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GTakeCommonOfDiff(*args)

    @staticmethod
    def GTakeCommonOfSame(*args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        G: TopOpeBRepBuild_GTopo

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GTakeCommonOfSame(*args)

    def GToMerge(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GToMerge(self, *args)

    def GToSplit(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        TB: TopAbs_State

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GToSplit(self, *args)

    def GWESMakeFaces(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        FF: TopoDS_Shape
        WES: TopOpeBRepBuild_WireEdgeSet
        LOF: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GWESMakeFaces(self, *args)

    @staticmethod
    def GcheckNBOUNDS(*args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Shape

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GcheckNBOUNDS(*args)

    def GdumpEDBU(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        EB: TopOpeBRepBuild_EdgeBuilder

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GdumpEDBU(self, *args)

    def GdumpEDG(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        str: Standard_Address,optional
        	default value is NULL

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GdumpEDG(self, *args)

    def GdumpEDGVER(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Shape
        V: TopoDS_Shape
        str: Standard_Address,optional
        	default value is NULL

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GdumpEDGVER(self, *args)

    def GdumpEXP(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        E: TopOpeBRepTool_ShapeExplorer

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GdumpEXP(self, *args)

    def GdumpFABU(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        FB: TopOpeBRepBuild_FaceBuilder

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GdumpFABU(self, *args)

    def GdumpLS(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        L: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GdumpLS(self, *args)

    @staticmethod
    def GdumpORIPARPNT(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        o: TopAbs_Orientation
        p: float
        Pnt: gp_Pnt

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GdumpORIPARPNT(*args)

    @staticmethod
    def GdumpPNT(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        P: gp_Pnt

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GdumpPNT(*args)

    def GdumpSAMDOM(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        L: TopTools_ListOfShape
        str: Standard_Address,optional
        	default value is NULL

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GdumpSAMDOM(self, *args)

    def GdumpSHA(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        str: Standard_Address,optional
        	default value is NULL

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GdumpSHA(self, *args)

    def GdumpSHAORI(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        str: Standard_Address,optional
        	default value is NULL

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GdumpSHAORI(self, *args)

    def GdumpSHAORIGEO(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        str: Standard_Address,optional
        	default value is NULL

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GdumpSHAORIGEO(self, *args)

    def GdumpSHASETindex(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GdumpSHASETindex(self, *args)

    def GdumpSHASETreset(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GdumpSHASETreset(self, *args)

    def GdumpSHASTA(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        iS: int
        T: TopAbs_State
        a: TCollection_AsciiString,optional
        	default value is 
        b: TCollection_AsciiString,optional
        	default value is 

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        T: TopAbs_State
        a: TCollection_AsciiString,optional
        	default value is 
        b: TCollection_AsciiString,optional
        	default value is 

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        iS: int
        T: TopAbs_State
        SS: TopOpeBRepBuild_ShapeSet
        a: TCollection_AsciiString,optional
        	default value is 
        b: TCollection_AsciiString,optional
        	default value is 
        c: TCollection_AsciiString,optional
        	default value is '
        '

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GdumpSHASTA(self, *args)

    def GdumpSOBU(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SB: TopOpeBRepBuild_SolidBuilder

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GdumpSOBU(self, *args)

    def GtraceSPS(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        iS: int

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        iS: int
        jS: int

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        IS: int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GtraceSPS(self, *args)

    def InitSection(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_InitSection(self, *args)

    def IsKPart(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_IsKPart(self, *args)

    def IsMerged(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the shape <s> has been merged.

        Parameters
        ----------
        S: TopoDS_Shape
        TB: TopAbs_State

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_IsMerged(self, *args)

    def IsShapeOf(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        I12: int

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_IsShapeOf(self, *args)

    def IsSplit(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the shape <s> has been split.

        Parameters
        ----------
        S: TopoDS_Shape
        TB: TopAbs_State

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_IsSplit(self, *args)

    def KPClearMaps(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPClearMaps(self, *args)

    @staticmethod
    def KPContains(*args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        L: TopTools_ListOfShape

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPContains(*args)

    def KPSameDomain(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        L1: TopTools_ListOfShape
        L2: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPSameDomain(self, *args)

    def KPclasSS(self, *args) -> "TopAbs_State":
        r"""
        No available documentation.

        Parameters
        ----------
        S1: TopoDS_Shape
        exceptLS1: TopTools_ListOfShape
        S2: TopoDS_Shape

        Returns
        -------
        TopAbs_State
        No available documentation.

        Parameters
        ----------
        S1: TopoDS_Shape
        exceptS1: TopoDS_Shape
        S2: TopoDS_Shape

        Returns
        -------
        TopAbs_State
        No available documentation.

        Parameters
        ----------
        S1: TopoDS_Shape
        S2: TopoDS_Shape

        Returns
        -------
        TopAbs_State

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPclasSS(self, *args)

    def KPclassF(self, *args) -> "TopAbs_State":
        r"""
        No available documentation.

        Parameters
        ----------
        F1: TopoDS_Shape
        F2: TopoDS_Shape

        Returns
        -------
        TopAbs_State

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPclassF(self, *args)

    def KPclassFF(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        F1: TopoDS_Shape
        F2: TopoDS_Shape
        T1: TopAbs_State
        T2: TopAbs_State

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPclassFF(self, *args)

    def KPisdisj(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPisdisj(self, *args)

    def KPisdisjanalyse(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ST1: TopAbs_State
        ST2: TopAbs_State

        Returns
        -------
        I: int
        IC1: int
        IC2: int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPisdisjanalyse(self, *args)

    def KPisdisjsh(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPisdisjsh(self, *args)

    def KPisfafa(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPisfafa(self, *args)

    def KPisfafash(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPisfafash(self, *args)

    def KPiskole(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPiskole(self, *args)

    def KPiskoleFF(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        F1: TopoDS_Shape
        F2: TopoDS_Shape
        T1: TopAbs_State
        T2: TopAbs_State

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPiskoleFF(self, *args)

    def KPiskoleanalyse(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        FT1: TopAbs_State
        FT2: TopAbs_State
        ST1: TopAbs_State
        ST2: TopAbs_State

        Returns
        -------
        I: int
        I1: int
        I2: int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPiskoleanalyse(self, *args)

    def KPiskolesh(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        LS: TopTools_ListOfShape
        LF: TopTools_ListOfShape

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPiskolesh(self, *args)

    def KPiskoletge(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPiskoletge(self, *args)

    def KPiskoletgeanalyse(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Conf: TopOpeBRepDS_Config
        ST1: TopAbs_State
        ST2: TopAbs_State

        Returns
        -------
        I: int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPiskoletgeanalyse(self, *args)

    def KPiskoletgesh(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        LS: TopTools_ListOfShape
        LF: TopTools_ListOfShape

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPiskoletgesh(self, *args)

    def KPissoso(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPissoso(self, *args)

    def KPissososh(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPissososh(self, *args)

    def KPlhg(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        T: TopAbs_ShapeEnum
        L: TopTools_ListOfShape

        Returns
        -------
        int
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        T: TopAbs_ShapeEnum

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPlhg(self, *args)

    def KPlhsd(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        T: TopAbs_ShapeEnum
        L: TopTools_ListOfShape

        Returns
        -------
        int
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        T: TopAbs_ShapeEnum

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPlhsd(self, *args)

    @staticmethod
    def KPls(*args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        T: TopAbs_ShapeEnum
        L: TopTools_ListOfShape

        Returns
        -------
        int
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        T: TopAbs_ShapeEnum

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPls(*args)

    def KPmakeface(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        F1: TopoDS_Shape
        LF2: TopTools_ListOfShape
        T1: TopAbs_State
        T2: TopAbs_State
        R1: bool
        R2: bool

        Returns
        -------
        TopoDS_Shape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPmakeface(self, *args)

    @staticmethod
    def KPreturn(*args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        KP: int

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPreturn(*args)

    def KeepShape(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        LS: TopTools_ListOfShape
        T: TopAbs_State

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KeepShape(self, *args)

    def MSplit(self, *args) -> "TopOpeBRepDS_DataMapOfShapeListOfShapeOn1State const &":
        r"""
        No available documentation.

        Parameters
        ----------
        s: TopAbs_State

        Returns
        -------
        TopOpeBRepDS_DataMapOfShapeListOfShapeOn1State

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_MSplit(self, *args)

    def MakeEdges(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Shape
        B: TopOpeBRepBuild_EdgeBuilder
        L: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_MakeEdges(self, *args)

    def MakeFaces(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Shape
        B: TopOpeBRepBuild_FaceBuilder
        L: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_MakeFaces(self, *args)

    def MakeShells(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        B: TopOpeBRepBuild_SolidBuilder
        L: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_MakeShells(self, *args)

    def MakeSolids(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        B: TopOpeBRepBuild_SolidBuilder
        L: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_MakeSolids(self, *args)

    def MapShapes(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        S1: TopoDS_Shape
        S2: TopoDS_Shape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_MapShapes(self, *args)

    def MergeEdges(self, *args) -> "void":
        r"""
        Merges the two edges <s1> and <s2> keeping the parts in each edge of states <tb1> and <tb2>. booleans ona, onb, onab indicate wheter parts of edges found as state on respectively on first, second, and both shapes must be (or not) built.

        Parameters
        ----------
        L1: TopTools_ListOfShape
        TB1: TopAbs_State
        L2: TopTools_ListOfShape
        TB2: TopAbs_State
        onA: bool,optional
        	default value is Standard_False
        onB: bool,optional
        	default value is Standard_False
        onAB: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_MergeEdges(self, *args)

    def MergeFaces(self, *args) -> "void":
        r"""
        Merges the two faces <s1> and <s2> keeping the parts in each face of states <tb1> and <tb2>.

        Parameters
        ----------
        S1: TopTools_ListOfShape
        TB1: TopAbs_State
        S2: TopTools_ListOfShape
        TB2: TopAbs_State
        onA: bool,optional
        	default value is Standard_False
        onB: bool,optional
        	default value is Standard_False
        onAB: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_MergeFaces(self, *args)

    def MergeKPart(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        TB1: TopAbs_State
        TB2: TopAbs_State

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_MergeKPart(self, *args)

    def MergeKPartisdisj(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_MergeKPartisdisj(self, *args)

    def MergeKPartisfafa(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_MergeKPartisfafa(self, *args)

    def MergeKPartiskole(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_MergeKPartiskole(self, *args)

    def MergeKPartiskoletge(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_MergeKPartiskoletge(self, *args)

    def MergeKPartissoso(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_MergeKPartissoso(self, *args)

    def MergeShapes(self, *args) -> "void":
        r"""
        Merges the two shapes <s1> and <s2> keeping the parts of states <tb1>,<tb2> in <s1>,<s2>.

        Parameters
        ----------
        S1: TopoDS_Shape
        TB1: TopAbs_State
        S2: TopoDS_Shape
        TB2: TopAbs_State

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_MergeShapes(self, *args)

    def MergeSolid(self, *args) -> "void":
        r"""
        Merges the solid <s> keeping the parts of state <tb>.

        Parameters
        ----------
        S: TopoDS_Shape
        TB: TopAbs_State

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_MergeSolid(self, *args)

    def MergeSolids(self, *args) -> "void":
        r"""
        Merges the two solids <s1> and <s2> keeping the parts in each solid of states <tb1> and <tb2>.

        Parameters
        ----------
        S1: TopoDS_Shape
        TB1: TopAbs_State
        S2: TopoDS_Shape
        TB2: TopAbs_State

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_MergeSolids(self, *args)

    def Merged(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns the merged parts <tb> of shape <s>.

        Parameters
        ----------
        S: TopoDS_Shape
        TB: TopAbs_State

        Returns
        -------
        TopTools_ListOfShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_Merged(self, *args)

    def NewEdges(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns the edges created on curve <i>.

        Parameters
        ----------
        I: int

        Returns
        -------
        TopTools_ListOfShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_NewEdges(self, *args)

    def NewFaces(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns the faces created on surface <i>.

        Parameters
        ----------
        I: int

        Returns
        -------
        TopTools_ListOfShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_NewFaces(self, *args)

    def NewVertex(self, *args) -> "TopoDS_Shape const":
        r"""
        Returns the vertex created on point <i>.

        Parameters
        ----------
        I: int

        Returns
        -------
        TopoDS_Shape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_NewVertex(self, *args)

    def Opec12(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_Opec12(self, *args)

    def Opec21(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_Opec21(self, *args)

    def Opecom(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_Opecom(self, *args)

    def Opefus(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_Opefus(self, *args)

    @staticmethod
    def Orient(*args) -> "TopAbs_Orientation":
        r"""
        No available documentation.

        Parameters
        ----------
        O: TopAbs_Orientation
        R: bool

        Returns
        -------
        TopAbs_Orientation

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_Orient(*args)

    def Perform(self, *args) -> "void":
        r"""
        Stores the data structure <hds>, create shapes from the new geometries.

        Parameters
        ----------
        HDS: TopOpeBRepDS_HDataStructure

        Returns
        -------
        None
        Stores the data structure <hds>, create shapes from the new geometries, evaluates if an operation performed on shapes s1,s2 is a particular case.

        Parameters
        ----------
        HDS: TopOpeBRepDS_HDataStructure
        S1: TopoDS_Shape
        S2: TopoDS_Shape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_Perform(self, *args)

    @staticmethod
    def PrintCur(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_PrintCur(*args)

    @staticmethod
    def PrintGeo(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_PrintGeo(*args)

    @staticmethod
    def PrintOri(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_PrintOri(*args)

    @staticmethod
    def PrintPnt(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        V: TopoDS_Vertex

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_PrintPnt(*args)

    @staticmethod
    def PrintSur(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_PrintSur(*args)

    def RegularizeFace(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        FF: TopoDS_Shape
        newFace: TopoDS_Shape
        LOF: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_RegularizeFace(self, *args)

    def RegularizeFaces(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        FF: TopoDS_Shape
        lnewFace: TopTools_ListOfShape
        LOF: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_RegularizeFaces(self, *args)

    def RegularizeSolid(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SS: TopoDS_Shape
        newSolid: TopoDS_Shape
        LOS: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_RegularizeSolid(self, *args)

    def RegularizeSolids(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SS: TopoDS_Shape
        lnewSolid: TopTools_ListOfShape
        LOS: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_RegularizeSolids(self, *args)

    @staticmethod
    def Reverse(*args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        T1: TopAbs_State
        T2: TopAbs_State

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_Reverse(*args)

    def Section(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Return all section edges.

        Parameters
        ----------
        L: TopTools_ListOfShape

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_Section(self, *args)

    def SectionCurves(self, *args) -> "void":
        r"""
        Return the section edges built on new curves.

        Parameters
        ----------
        L: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_SectionCurves(self, *args)

    def SectionEdges(self, *args) -> "void":
        r"""
        Return the parts of edges found on the boundary of the two arguments s1,s2 of perform().

        Parameters
        ----------
        L: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_SectionEdges(self, *args)

    def ShapePosition(self, *args) -> "TopAbs_State":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        LS: TopTools_ListOfShape

        Returns
        -------
        TopAbs_State

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_ShapePosition(self, *args)

    def ShapeRank(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_ShapeRank(self, *args)

    def SplitEvisoONperiodicF(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_SplitEvisoONperiodicF(self, *args)

    def SplitSectionEdge(self, *args) -> "void":
        r"""
        Create parts on solid of section edges.

        Parameters
        ----------
        E: TopoDS_Shape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_SplitSectionEdge(self, *args)

    def SplitSectionEdges(self, *args) -> "void":
        r"""
        Create parts on solid of section edges.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_SplitSectionEdges(self, *args)

    def Splits(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns the split parts <tb> of shape <s>.

        Parameters
        ----------
        S: TopoDS_Shape
        TB: TopAbs_State

        Returns
        -------
        TopTools_ListOfShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_Splits(self, *args)

    @staticmethod
    def StringState(*args) -> "TCollection_AsciiString":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopAbs_State

        Returns
        -------
        TCollection_AsciiString

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_StringState(*args)

    @staticmethod
    def TopType(*args) -> "TopAbs_ShapeEnum":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        TopAbs_ShapeEnum

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_TopType(*args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_Builder

# Register TopOpeBRepBuild_Builder in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_Builder_swigregister(TopOpeBRepBuild_Builder)

def TopOpeBRepBuild_Builder_Contains(*args) -> "Standard_Boolean":
    r"""
    No available documentation.

    Parameters
    ----------
    S: TopoDS_Shape
    L: TopTools_ListOfShape

    Returns
    -------
    bool

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_Contains(*args)

def TopOpeBRepBuild_Builder_GContains(*args) -> "Standard_Boolean":
    r"""
    No available documentation.

    Parameters
    ----------
    S: TopoDS_Shape
    L: TopTools_ListOfShape

    Returns
    -------
    bool

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GContains(*args)

def TopOpeBRepBuild_Builder_GCopyList(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    Lin: TopTools_ListOfShape
    i1: int
    i2: int
    Lou: TopTools_ListOfShape

    Returns
    -------
    None
    No available documentation.

    Parameters
    ----------
    Lin: TopTools_ListOfShape
    Lou: TopTools_ListOfShape

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GCopyList(*args)

def TopOpeBRepBuild_Builder_GTakeCommonOfDiff(*args) -> "Standard_Boolean":
    r"""
    No available documentation.

    Parameters
    ----------
    G: TopOpeBRepBuild_GTopo

    Returns
    -------
    bool

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GTakeCommonOfDiff(*args)

def TopOpeBRepBuild_Builder_GTakeCommonOfSame(*args) -> "Standard_Boolean":
    r"""
    No available documentation.

    Parameters
    ----------
    G: TopOpeBRepBuild_GTopo

    Returns
    -------
    bool

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GTakeCommonOfSame(*args)

def TopOpeBRepBuild_Builder_GcheckNBOUNDS(*args) -> "Standard_Boolean":
    r"""
    No available documentation.

    Parameters
    ----------
    E: TopoDS_Shape

    Returns
    -------
    bool

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GcheckNBOUNDS(*args)

def TopOpeBRepBuild_Builder_GdumpORIPARPNT(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    o: TopAbs_Orientation
    p: float
    Pnt: gp_Pnt

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GdumpORIPARPNT(*args)

def TopOpeBRepBuild_Builder_GdumpPNT(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    P: gp_Pnt

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_GdumpPNT(*args)

def TopOpeBRepBuild_Builder_KPContains(*args) -> "Standard_Boolean":
    r"""
    No available documentation.

    Parameters
    ----------
    S: TopoDS_Shape
    L: TopTools_ListOfShape

    Returns
    -------
    bool

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPContains(*args)

def TopOpeBRepBuild_Builder_KPls(*args) -> "Standard_Integer":
    r"""
    No available documentation.

    Parameters
    ----------
    S: TopoDS_Shape
    T: TopAbs_ShapeEnum
    L: TopTools_ListOfShape

    Returns
    -------
    int
    No available documentation.

    Parameters
    ----------
    S: TopoDS_Shape
    T: TopAbs_ShapeEnum

    Returns
    -------
    int

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPls(*args)

def TopOpeBRepBuild_Builder_KPreturn(*args) -> "Standard_Integer":
    r"""
    No available documentation.

    Parameters
    ----------
    KP: int

    Returns
    -------
    int

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_KPreturn(*args)

def TopOpeBRepBuild_Builder_Orient(*args) -> "TopAbs_Orientation":
    r"""
    No available documentation.

    Parameters
    ----------
    O: TopAbs_Orientation
    R: bool

    Returns
    -------
    TopAbs_Orientation

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_Orient(*args)

def TopOpeBRepBuild_Builder_PrintCur(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    E: TopoDS_Edge

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_PrintCur(*args)

def TopOpeBRepBuild_Builder_PrintGeo(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    S: TopoDS_Shape

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_PrintGeo(*args)

def TopOpeBRepBuild_Builder_PrintOri(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    S: TopoDS_Shape

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_PrintOri(*args)

def TopOpeBRepBuild_Builder_PrintPnt(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    V: TopoDS_Vertex

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_PrintPnt(*args)

def TopOpeBRepBuild_Builder_PrintSur(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    F: TopoDS_Face

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_PrintSur(*args)

def TopOpeBRepBuild_Builder_Reverse(*args) -> "Standard_Boolean":
    r"""
    No available documentation.

    Parameters
    ----------
    T1: TopAbs_State
    T2: TopAbs_State

    Returns
    -------
    bool

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_Reverse(*args)

def TopOpeBRepBuild_Builder_StringState(*args) -> "TCollection_AsciiString":
    r"""
    No available documentation.

    Parameters
    ----------
    S: TopAbs_State

    Returns
    -------
    TCollection_AsciiString

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_StringState(*args)

def TopOpeBRepBuild_Builder_TopType(*args) -> "TopAbs_ShapeEnum":
    r"""
    No available documentation.

    Parameters
    ----------
    S: TopoDS_Shape

    Returns
    -------
    TopAbs_ShapeEnum

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Builder_TopType(*args)

class TopOpeBRepBuild_BuilderON(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        PB: TopOpeBRepBuild_PBuilder
        F: TopoDS_Shape
        PG: TopOpeBRepBuild_PGTopo
        PLSclass: TopOpeBRepTool_Plos
        PWES: TopOpeBRepBuild_PWireEdgeSet

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_BuilderON_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_BuilderON(*args))

    def GFillONCheckI(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        I: TopOpeBRepDS_Interference

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_BuilderON_GFillONCheckI(self, *args)

    def GFillONParts2dWES2(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        I: TopOpeBRepDS_Interference
        EspON: TopoDS_Shape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_BuilderON_GFillONParts2dWES2(self, *args)

    def GFillONPartsWES1(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        I: TopOpeBRepDS_Interference

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_BuilderON_GFillONPartsWES1(self, *args)

    def GFillONPartsWES2(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        I: TopOpeBRepDS_Interference
        EspON: TopoDS_Shape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_BuilderON_GFillONPartsWES2(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        PB: TopOpeBRepBuild_PBuilder
        F: TopoDS_Shape
        PG: TopOpeBRepBuild_PGTopo
        PLSclass: TopOpeBRepTool_Plos
        PWES: TopOpeBRepBuild_PWireEdgeSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_BuilderON_Perform(self, *args)

    def Perform2d(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        PB: TopOpeBRepBuild_PBuilder
        F: TopoDS_Shape
        PG: TopOpeBRepBuild_PGTopo
        PLSclass: TopOpeBRepTool_Plos
        PWES: TopOpeBRepBuild_PWireEdgeSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_BuilderON_Perform2d(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_BuilderON

# Register TopOpeBRepBuild_BuilderON in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_BuilderON_swigregister(TopOpeBRepBuild_BuilderON)

class TopOpeBRepBuild_CorrectFace2d(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        aFace: TopoDS_Face
        anAvoidMap: TopTools_IndexedMapOfOrientedShape
        aMap: TopTools_IndexedDataMapOfShapeShape

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_CorrectFace2d_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_CorrectFace2d(*args))

    @staticmethod
    def CheckList(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aFace: TopoDS_Face
        aHeadList: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_CorrectFace2d_CheckList(*args)

    def CorrectedFace(self, *args) -> "TopoDS_Face const":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Face

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_CorrectFace2d_CorrectedFace(self, *args)

    def ErrorStatus(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_CorrectFace2d_ErrorStatus(self, *args)

    def Face(self, *args) -> "TopoDS_Face const":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Face

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_CorrectFace2d_Face(self, *args)

    @staticmethod
    def GetP2dFL(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aFace: TopoDS_Face
        anEdge: TopoDS_Edge
        P2dF: gp_Pnt2d
        P2dL: gp_Pnt2d

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_CorrectFace2d_GetP2dFL(*args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_CorrectFace2d_IsDone(self, *args)

    def MapOfTrans2dInfo(self, *args) -> "TopTools_IndexedDataMapOfShapeShape &":
        r"""
        No available documentation.

        Returns
        -------
        TopTools_IndexedDataMapOfShapeShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_CorrectFace2d_MapOfTrans2dInfo(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_CorrectFace2d_Perform(self, *args)

    def SetMapOfTrans2dInfo(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMap: TopTools_IndexedDataMapOfShapeShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_CorrectFace2d_SetMapOfTrans2dInfo(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_CorrectFace2d

# Register TopOpeBRepBuild_CorrectFace2d in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_CorrectFace2d_swigregister(TopOpeBRepBuild_CorrectFace2d)

def TopOpeBRepBuild_CorrectFace2d_CheckList(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aFace: TopoDS_Face
    aHeadList: TopTools_ListOfShape

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_CorrectFace2d_CheckList(*args)

def TopOpeBRepBuild_CorrectFace2d_GetP2dFL(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aFace: TopoDS_Face
    anEdge: TopoDS_Edge
    P2dF: gp_Pnt2d
    P2dL: gp_Pnt2d

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_CorrectFace2d_GetP2dFL(*args)

class TopOpeBRepBuild_FaceBuilder(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        Create a facebuilder to build the faces on the shapes (wires, blocks of edge) described by <ls>.

        Parameters
        ----------
        ES: TopOpeBRepBuild_WireEdgeSet
        F: TopoDS_Shape
        ForceClass: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_FaceBuilder_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_FaceBuilder(*args))

    def AddEdgeWire(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Shape
        W: TopoDS_Shape

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FaceBuilder_AddEdgeWire(self, *args)

    def CorrectGclosedWire(self, *args) -> "void":
        r"""
        Using the given maps, change the topology of the 3d-closed wires, in order to get closed wires.

        Parameters
        ----------
        mapVVref: TopTools_IndexedDataMapOfShapeShape
        mapVon1Edge: TopTools_IndexedDataMapOfShapeShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FaceBuilder_CorrectGclosedWire(self, *args)

    def DetectPseudoInternalEdge(self, *args) -> "void":
        r"""
        Removes edges appearing twice (forward,reversed) with a bounding vertex not connected to any other edge. mape contains edges found. modifies myblockbuilder.

        Parameters
        ----------
        mapE: TopTools_IndexedMapOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FaceBuilder_DetectPseudoInternalEdge(self, *args)

    def DetectUnclosedWire(self, *args) -> "void":
        r"""
        Removes are non 3d-closed wires. fills up maps <mapvvsameg> and <mapvon1edge>, in order to correct 3d-closed but unclosed (topologic connexity) wires. modifies myblockbuilder.

        Parameters
        ----------
        mapVVsameG: TopTools_IndexedDataMapOfShapeShape
        mapVon1Edge: TopTools_IndexedDataMapOfShapeShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FaceBuilder_DetectUnclosedWire(self, *args)

    def Edge(self, *args) -> "TopoDS_Shape const":
        r"""
        Returns current new edge of current new wire.

        Returns
        -------
        TopoDS_Shape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FaceBuilder_Edge(self, *args)

    def EdgeConnexity(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Shape

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FaceBuilder_EdgeConnexity(self, *args)

    def Face(self, *args) -> "TopoDS_Shape const":
        r"""
        Return myface.

        Returns
        -------
        TopoDS_Shape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FaceBuilder_Face(self, *args)

    def FindNextValidElement(self, *args) -> "void":
        r"""
        Iterates on myblockiterator until finding a valid element.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FaceBuilder_FindNextValidElement(self, *args)

    def InitEdge(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FaceBuilder_InitEdge(self, *args)

    def InitFace(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FaceBuilder_InitFace(self, *args)

    def InitFaceBuilder(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ES: TopOpeBRepBuild_WireEdgeSet
        F: TopoDS_Shape
        ForceClass: bool

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FaceBuilder_InitFaceBuilder(self, *args)

    def InitWire(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FaceBuilder_InitWire(self, *args)

    def IsOldWire(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FaceBuilder_IsOldWire(self, *args)

    def MoreEdge(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FaceBuilder_MoreEdge(self, *args)

    def MoreFace(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FaceBuilder_MoreFace(self, *args)

    def MoreWire(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FaceBuilder_MoreWire(self, *args)

    def NextEdge(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FaceBuilder_NextEdge(self, *args)

    def NextFace(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FaceBuilder_NextFace(self, *args)

    def NextWire(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FaceBuilder_NextWire(self, *args)

    def OldWire(self, *args) -> "TopoDS_Shape const":
        r"""
        Returns current wire this wire may be : * an old wire oldwire(), which has not been reconstructed; * a new wire made of edges described by ...newedge() methods.

        Returns
        -------
        TopoDS_Shape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FaceBuilder_OldWire(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_FaceBuilder

# Register TopOpeBRepBuild_FaceBuilder in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_FaceBuilder_swigregister(TopOpeBRepBuild_FaceBuilder)

class TopOpeBRepBuild_FuseFace(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        LIF: TopTools_ListOfShape
        LRF: TopTools_ListOfShape
        CXM: int

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_FuseFace_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_FuseFace(*args))

    def ClearEdge(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FuseFace_ClearEdge(self, *args)

    def ClearVertex(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FuseFace_ClearVertex(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        LIF: TopTools_ListOfShape
        LRF: TopTools_ListOfShape
        CXM: int

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FuseFace_Init(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FuseFace_IsDone(self, *args)

    def IsModified(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FuseFace_IsModified(self, *args)

    def LExternEdge(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        No available documentation.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FuseFace_LExternEdge(self, *args)

    def LExternVertex(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        No available documentation.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FuseFace_LExternVertex(self, *args)

    def LFuseFace(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        No available documentation.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FuseFace_LFuseFace(self, *args)

    def LInternEdge(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        No available documentation.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FuseFace_LInternEdge(self, *args)

    def LInternVertex(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        No available documentation.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FuseFace_LInternVertex(self, *args)

    def LModifEdge(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        No available documentation.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FuseFace_LModifEdge(self, *args)

    def LModifVertex(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        No available documentation.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FuseFace_LModifVertex(self, *args)

    def PerformEdge(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FuseFace_PerformEdge(self, *args)

    def PerformFace(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FuseFace_PerformFace(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_FuseFace

# Register TopOpeBRepBuild_FuseFace in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_FuseFace_swigregister(TopOpeBRepBuild_FuseFace)

class TopOpeBRepBuild_GIter(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        G: TopOpeBRepBuild_GTopo

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_GIter_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_GIter(*args))

    def Current(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        s1: TopAbs_State
        s2: TopAbs_State

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GIter_Current(self, *args)

    def DumpToString(self) -> "std::string":
        r"""DumpToString(TopOpeBRepBuild_GIter self) -> std::string"""
        return _TopOpeBRepBuild.TopOpeBRepBuild_GIter_DumpToString(self)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        G: TopOpeBRepBuild_GTopo

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GIter_Init(self, *args)

    def More(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GIter_More(self, *args)

    def Next(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GIter_Next(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_GIter

# Register TopOpeBRepBuild_GIter in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_GIter_swigregister(TopOpeBRepBuild_GIter)

class TopOpeBRepBuild_GTool(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def DumpToString(self) -> "std::string":
        r"""DumpToString(TopOpeBRepBuild_GTool self) -> std::string"""
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTool_DumpToString(self)

    @staticmethod
    def GComDiff(*args) -> "TopOpeBRepBuild_GTopo":
        r"""
        No available documentation.

        Parameters
        ----------
        s1: TopAbs_ShapeEnum
        s2: TopAbs_ShapeEnum

        Returns
        -------
        TopOpeBRepBuild_GTopo

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTool_GComDiff(*args)

    @staticmethod
    def GComSame(*args) -> "TopOpeBRepBuild_GTopo":
        r"""
        No available documentation.

        Parameters
        ----------
        s1: TopAbs_ShapeEnum
        s2: TopAbs_ShapeEnum

        Returns
        -------
        TopOpeBRepBuild_GTopo

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTool_GComSame(*args)

    @staticmethod
    def GComUnsh(*args) -> "TopOpeBRepBuild_GTopo":
        r"""
        No available documentation.

        Parameters
        ----------
        s1: TopAbs_ShapeEnum
        s2: TopAbs_ShapeEnum

        Returns
        -------
        TopOpeBRepBuild_GTopo

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTool_GComUnsh(*args)

    @staticmethod
    def GCutDiff(*args) -> "TopOpeBRepBuild_GTopo":
        r"""
        No available documentation.

        Parameters
        ----------
        s1: TopAbs_ShapeEnum
        s2: TopAbs_ShapeEnum

        Returns
        -------
        TopOpeBRepBuild_GTopo

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTool_GCutDiff(*args)

    @staticmethod
    def GCutSame(*args) -> "TopOpeBRepBuild_GTopo":
        r"""
        No available documentation.

        Parameters
        ----------
        s1: TopAbs_ShapeEnum
        s2: TopAbs_ShapeEnum

        Returns
        -------
        TopOpeBRepBuild_GTopo

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTool_GCutSame(*args)

    @staticmethod
    def GCutUnsh(*args) -> "TopOpeBRepBuild_GTopo":
        r"""
        No available documentation.

        Parameters
        ----------
        s1: TopAbs_ShapeEnum
        s2: TopAbs_ShapeEnum

        Returns
        -------
        TopOpeBRepBuild_GTopo

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTool_GCutUnsh(*args)

    @staticmethod
    def GFusDiff(*args) -> "TopOpeBRepBuild_GTopo":
        r"""
        No available documentation.

        Parameters
        ----------
        s1: TopAbs_ShapeEnum
        s2: TopAbs_ShapeEnum

        Returns
        -------
        TopOpeBRepBuild_GTopo

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTool_GFusDiff(*args)

    @staticmethod
    def GFusSame(*args) -> "TopOpeBRepBuild_GTopo":
        r"""
        No available documentation.

        Parameters
        ----------
        s1: TopAbs_ShapeEnum
        s2: TopAbs_ShapeEnum

        Returns
        -------
        TopOpeBRepBuild_GTopo

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTool_GFusSame(*args)

    @staticmethod
    def GFusUnsh(*args) -> "TopOpeBRepBuild_GTopo":
        r"""
        No available documentation.

        Parameters
        ----------
        s1: TopAbs_ShapeEnum
        s2: TopAbs_ShapeEnum

        Returns
        -------
        TopOpeBRepBuild_GTopo

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTool_GFusUnsh(*args)

    __repr__ = _dumps_object


    def __init__(self):
        r"""__init__(TopOpeBRepBuild_GTool self) -> TopOpeBRepBuild_GTool"""
        _TopOpeBRepBuild.TopOpeBRepBuild_GTool_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_GTool())
    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_GTool

# Register TopOpeBRepBuild_GTool in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_GTool_swigregister(TopOpeBRepBuild_GTool)

def TopOpeBRepBuild_GTool_GComDiff(*args) -> "TopOpeBRepBuild_GTopo":
    r"""
    No available documentation.

    Parameters
    ----------
    s1: TopAbs_ShapeEnum
    s2: TopAbs_ShapeEnum

    Returns
    -------
    TopOpeBRepBuild_GTopo

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_GTool_GComDiff(*args)

def TopOpeBRepBuild_GTool_GComSame(*args) -> "TopOpeBRepBuild_GTopo":
    r"""
    No available documentation.

    Parameters
    ----------
    s1: TopAbs_ShapeEnum
    s2: TopAbs_ShapeEnum

    Returns
    -------
    TopOpeBRepBuild_GTopo

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_GTool_GComSame(*args)

def TopOpeBRepBuild_GTool_GComUnsh(*args) -> "TopOpeBRepBuild_GTopo":
    r"""
    No available documentation.

    Parameters
    ----------
    s1: TopAbs_ShapeEnum
    s2: TopAbs_ShapeEnum

    Returns
    -------
    TopOpeBRepBuild_GTopo

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_GTool_GComUnsh(*args)

def TopOpeBRepBuild_GTool_GCutDiff(*args) -> "TopOpeBRepBuild_GTopo":
    r"""
    No available documentation.

    Parameters
    ----------
    s1: TopAbs_ShapeEnum
    s2: TopAbs_ShapeEnum

    Returns
    -------
    TopOpeBRepBuild_GTopo

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_GTool_GCutDiff(*args)

def TopOpeBRepBuild_GTool_GCutSame(*args) -> "TopOpeBRepBuild_GTopo":
    r"""
    No available documentation.

    Parameters
    ----------
    s1: TopAbs_ShapeEnum
    s2: TopAbs_ShapeEnum

    Returns
    -------
    TopOpeBRepBuild_GTopo

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_GTool_GCutSame(*args)

def TopOpeBRepBuild_GTool_GCutUnsh(*args) -> "TopOpeBRepBuild_GTopo":
    r"""
    No available documentation.

    Parameters
    ----------
    s1: TopAbs_ShapeEnum
    s2: TopAbs_ShapeEnum

    Returns
    -------
    TopOpeBRepBuild_GTopo

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_GTool_GCutUnsh(*args)

def TopOpeBRepBuild_GTool_GFusDiff(*args) -> "TopOpeBRepBuild_GTopo":
    r"""
    No available documentation.

    Parameters
    ----------
    s1: TopAbs_ShapeEnum
    s2: TopAbs_ShapeEnum

    Returns
    -------
    TopOpeBRepBuild_GTopo

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_GTool_GFusDiff(*args)

def TopOpeBRepBuild_GTool_GFusSame(*args) -> "TopOpeBRepBuild_GTopo":
    r"""
    No available documentation.

    Parameters
    ----------
    s1: TopAbs_ShapeEnum
    s2: TopAbs_ShapeEnum

    Returns
    -------
    TopOpeBRepBuild_GTopo

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_GTool_GFusSame(*args)

def TopOpeBRepBuild_GTool_GFusUnsh(*args) -> "TopOpeBRepBuild_GTopo":
    r"""
    No available documentation.

    Parameters
    ----------
    s1: TopAbs_ShapeEnum
    s2: TopAbs_ShapeEnum

    Returns
    -------
    TopOpeBRepBuild_GTopo

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_GTool_GFusUnsh(*args)

class TopOpeBRepBuild_GTopo(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        II: bool
        IN: bool
        IO: bool
        NI: bool
        NN: bool
        NO: bool
        OI: bool
        ON: bool
        OO: bool
        t1: TopAbs_ShapeEnum
        t2: TopAbs_ShapeEnum
        C1: TopOpeBRepDS_Config
        C2: TopOpeBRepDS_Config

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_GTopo_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_GTopo(*args))

    def ChangeConfig(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        C1: TopOpeBRepDS_Config
        C2: TopOpeBRepDS_Config

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTopo_ChangeConfig(self, *args)

    def ChangeType(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        t1: TopAbs_ShapeEnum
        t2: TopAbs_ShapeEnum

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTopo_ChangeType(self, *args)

    def ChangeValue(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        i1: int
        i2: int
        b: bool

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        s1: TopAbs_State
        s2: TopAbs_State
        b: bool

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTopo_ChangeValue(self, *args)

    def Config1(self, *args) -> "TopOpeBRepDS_Config":
        r"""
        No available documentation.

        Returns
        -------
        TopOpeBRepDS_Config

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTopo_Config1(self, *args)

    def Config2(self, *args) -> "TopOpeBRepDS_Config":
        r"""
        No available documentation.

        Returns
        -------
        TopOpeBRepDS_Config

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTopo_Config2(self, *args)

    def CopyPermuted(self, *args) -> "TopOpeBRepBuild_GTopo":
        r"""
        No available documentation.

        Returns
        -------
        TopOpeBRepBuild_GTopo

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTopo_CopyPermuted(self, *args)

    def DumpTypeToString(self) -> "std::string":
        r"""DumpTypeToString(TopOpeBRepBuild_GTopo self) -> std::string"""
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTopo_DumpTypeToString(self)

    def GIndex(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopAbs_State

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTopo_GIndex(self, *args)

    def GState(self, *args) -> "TopAbs_State":
        r"""
        No available documentation.

        Parameters
        ----------
        I: int

        Returns
        -------
        TopAbs_State

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTopo_GState(self, *args)

    def Index(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        II: int

        Returns
        -------
        i1: int
        i2: int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTopo_Index(self, *args)

    def IsToReverse1(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTopo_IsToReverse1(self, *args)

    def IsToReverse2(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTopo_IsToReverse2(self, *args)

    def Reset(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTopo_Reset(self, *args)

    def Reverse(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTopo_Reverse(self, *args)

    def Set(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        II: bool
        IN: bool
        IO: bool
        NI: bool
        NN: bool
        NO: bool
        OI: bool
        ON: bool
        OO: bool

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTopo_Set(self, *args)

    def SetReverse(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        rev: bool

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTopo_SetReverse(self, *args)

    def StatesON(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        s1: TopAbs_State
        s2: TopAbs_State

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTopo_StatesON(self, *args)

    def Type(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        t1: TopAbs_ShapeEnum
        t2: TopAbs_ShapeEnum

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTopo_Type(self, *args)

    def Value(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        s1: TopAbs_State
        s2: TopAbs_State

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        I1: int
        I2: int

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        II: int

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_GTopo_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_GTopo

# Register TopOpeBRepBuild_GTopo in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_GTopo_swigregister(TopOpeBRepBuild_GTopo)

class TopOpeBRepBuild_HBuilder(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        BT: TopOpeBRepDS_BuildTool

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_HBuilder(*args))

    def BuildTool(self, *args) -> "TopOpeBRepDS_BuildTool const &":
        r"""
        No available documentation.

        Returns
        -------
        TopOpeBRepDS_BuildTool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_BuildTool(self, *args)

    def ChangeBuildTool(self, *args) -> "TopOpeBRepDS_BuildTool &":
        r"""
        No available documentation.

        Returns
        -------
        TopOpeBRepDS_BuildTool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_ChangeBuildTool(self, *args)

    def ChangeBuilder(self, *args) -> "TopOpeBRepBuild_Builder &":
        r"""
        No available documentation.

        Returns
        -------
        TopOpeBRepBuild_Builder

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_ChangeBuilder(self, *args)

    def ChangeNewEdges(self, *args) -> "TopTools_ListOfShape &":
        r"""
        Returns the edges created on curve <i>.

        Parameters
        ----------
        I: int

        Returns
        -------
        TopTools_ListOfShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_ChangeNewEdges(self, *args)

    def Clear(self, *args) -> "void":
        r"""
        Removes all split and merge already performed. does not clear the handled ds.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_Clear(self, *args)

    def CurrentSection(self, *args) -> "TopoDS_Shape const":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Shape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_CurrentSection(self, *args)

    def DataStructure(self, *args) -> "opencascade::handle< TopOpeBRepDS_HDataStructure >":
        r"""
        Returns the ds handled by this builder.

        Returns
        -------
        opencascade::handle<TopOpeBRepDS_HDataStructure>

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_DataStructure(self, *args)

    def EdgeCurveAncestors(self, *args) -> "Standard_Boolean":
        r"""
        Search for the couple of face f1,f2 (from arguments of supra perform(s1,s2,hds)) method which intersection gives section edge e built on an intersection curve. returns true if f1,f2 have been valued. returns false if e is not a section edge built on intersection curve ic.

        Parameters
        ----------
        E: TopoDS_Shape
        F1: TopoDS_Shape
        F2: TopoDS_Shape

        Returns
        -------
        IC: int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_EdgeCurveAncestors(self, *args)

    def EdgeSectionAncestors(self, *args) -> "Standard_Boolean":
        r"""
        Search for the couple of face f1,f2 (from arguments of supra perform(s1,s2,hds)) method which intersection gives section edge e built on at least one edge . returns true if f1,f2 have been valued. returns false if e is not a section edge built on at least one edge of s1 and/or s2. le1,le2 are edges of s1,s2 which common part is edge e. le1 or le2 may be empty() but not both.

        Parameters
        ----------
        E: TopoDS_Shape
        LF1: TopTools_ListOfShape
        LF2: TopTools_ListOfShape
        LE1: TopTools_ListOfShape
        LE2: TopTools_ListOfShape

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_EdgeSectionAncestors(self, *args)

    def GetDSCurveFromSectEdge(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        SectEdge: TopoDS_Shape

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_GetDSCurveFromSectEdge(self, *args)

    def GetDSEdgeFromSectEdge(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Shape
        rank: int

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_GetDSEdgeFromSectEdge(self, *args)

    def GetDSFaceFromDSCurve(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        indexCur: int
        rank: int

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_GetDSFaceFromDSCurve(self, *args)

    def GetDSFaceFromDSEdge(self, *args) -> "TColStd_ListOfInteger &":
        r"""
        No available documentation.

        Parameters
        ----------
        indexEdg: int
        rank: int

        Returns
        -------
        TColStd_ListOfInteger

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_GetDSFaceFromDSEdge(self, *args)

    def GetDSPointFromNewVertex(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        NewVert: TopoDS_Shape

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_GetDSPointFromNewVertex(self, *args)

    def InitExtendedSectionDS(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        k: int,optional
        	default value is 3

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_InitExtendedSectionDS(self, *args)

    def InitSection(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        k: int,optional
        	default value is 3

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_InitSection(self, *args)

    def IsKPart(self, *args) -> "Standard_Integer":
        r"""
        Returns 0 is standard operation, != 0 if particular case.

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_IsKPart(self, *args)

    def IsMerged(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the shape <s> has been merged.

        Parameters
        ----------
        S: TopoDS_Shape
        ToBuild: TopAbs_State

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_IsMerged(self, *args)

    def IsSplit(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the shape <s> has been split.

        Parameters
        ----------
        S: TopoDS_Shape
        ToBuild: TopAbs_State

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_IsSplit(self, *args)

    def MergeKPart(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        TB1: TopAbs_State
        TB2: TopAbs_State

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_MergeKPart(self, *args)

    def MergeShapes(self, *args) -> "void":
        r"""
        Merges the two shapes <s1> and <s2> keeping the parts of states <tb1>,<tb2> in <s1>,<s2>.

        Parameters
        ----------
        S1: TopoDS_Shape
        TB1: TopAbs_State
        S2: TopoDS_Shape
        TB2: TopAbs_State

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_MergeShapes(self, *args)

    def MergeSolid(self, *args) -> "void":
        r"""
        Merges the solid <s> keeping the parts of state <tb>.

        Parameters
        ----------
        S: TopoDS_Shape
        TB: TopAbs_State

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_MergeSolid(self, *args)

    def MergeSolids(self, *args) -> "void":
        r"""
        Merges the two solids <s1> and <s2> keeping the parts in each solid of states <tb1> and <tb2>.

        Parameters
        ----------
        S1: TopoDS_Shape
        TB1: TopAbs_State
        S2: TopoDS_Shape
        TB2: TopAbs_State

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_MergeSolids(self, *args)

    def Merged(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns the merged parts <tobuild> of shape <s>.

        Parameters
        ----------
        S: TopoDS_Shape
        ToBuild: TopAbs_State

        Returns
        -------
        TopTools_ListOfShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_Merged(self, *args)

    def MoreSection(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_MoreSection(self, *args)

    def NewEdges(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns the edges created on curve <i>.

        Parameters
        ----------
        I: int

        Returns
        -------
        TopTools_ListOfShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_NewEdges(self, *args)

    def NewFaces(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns the faces created on surface <i>.

        Parameters
        ----------
        I: int

        Returns
        -------
        TopTools_ListOfShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_NewFaces(self, *args)

    def NewVertex(self, *args) -> "TopoDS_Shape const":
        r"""
        Returns the vertex created on point <i>.

        Parameters
        ----------
        I: int

        Returns
        -------
        TopoDS_Shape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_NewVertex(self, *args)

    def NextSection(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_NextSection(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        Stores the data structure <hds>, create shapes from the new geometries described in <hds>.

        Parameters
        ----------
        HDS: TopOpeBRepDS_HDataStructure

        Returns
        -------
        None
        Same as previous + evaluates if an operation performed on shapes s1,s2 is a particular case.

        Parameters
        ----------
        HDS: TopOpeBRepDS_HDataStructure
        S1: TopoDS_Shape
        S2: TopoDS_Shape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_Perform(self, *args)

    def Section(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        No available documentation.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_Section(self, *args)

    def Splits(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns the split parts <tobuild> of shape <s>.

        Parameters
        ----------
        S: TopoDS_Shape
        ToBuild: TopAbs_State

        Returns
        -------
        TopTools_ListOfShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_Splits(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_TopOpeBRepBuild_HBuilder_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_HBuilder

# Register TopOpeBRepBuild_HBuilder in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_HBuilder_swigregister(TopOpeBRepBuild_HBuilder)

class TopOpeBRepBuild_Loop(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        BI: TopOpeBRepBuild_BlockIterator

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_Loop_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_Loop(*args))

    def BlockIterator(self, *args) -> "TopOpeBRepBuild_BlockIterator const &":
        r"""
        No available documentation.

        Returns
        -------
        TopOpeBRepBuild_BlockIterator

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Loop_BlockIterator(self, *args)

    def Dump(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Loop_Dump(self, *args)

    def IsShape(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Loop_IsShape(self, *args)

    def Shape(self, *args) -> "TopoDS_Shape const":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Shape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Loop_Shape(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_TopOpeBRepBuild_Loop_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_Loop

# Register TopOpeBRepBuild_Loop in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_Loop_swigregister(TopOpeBRepBuild_Loop)

class TopOpeBRepBuild_LoopClassifier(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def Compare(self, *args) -> "TopAbs_State":
        r"""
        Returns the state of loop <l1> compared with loop <l2>.

        Parameters
        ----------
        L1: TopOpeBRepBuild_Loop
        L2: TopOpeBRepBuild_Loop

        Returns
        -------
        TopAbs_State

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_LoopClassifier_Compare(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_LoopClassifier

# Register TopOpeBRepBuild_LoopClassifier in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_LoopClassifier_swigregister(TopOpeBRepBuild_LoopClassifier)

class TopOpeBRepBuild_LoopSet(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_LoopSet_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_LoopSet(*args))

    def ChangeListOfLoop(self, *args) -> "TopOpeBRepBuild_ListOfLoop &":
        r"""
        No available documentation.

        Returns
        -------
        TopOpeBRepBuild_ListOfLoop

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_LoopSet_ChangeListOfLoop(self, *args)

    def InitLoop(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_LoopSet_InitLoop(self, *args)

    def Loop(self, *args) -> "opencascade::handle< TopOpeBRepBuild_Loop >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TopOpeBRepBuild_Loop>

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_LoopSet_Loop(self, *args)

    def MoreLoop(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_LoopSet_MoreLoop(self, *args)

    def NextLoop(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_LoopSet_NextLoop(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_LoopSet

# Register TopOpeBRepBuild_LoopSet in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_LoopSet_swigregister(TopOpeBRepBuild_LoopSet)

class TopOpeBRepBuild_ShapeListOfShape(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        L: TopTools_ListOfShape

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_ShapeListOfShape_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_ShapeListOfShape(*args))

    def ChangeList(self, *args) -> "TopTools_ListOfShape &":
        r"""
        No available documentation.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeListOfShape_ChangeList(self, *args)

    def ChangeShape(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Shape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeListOfShape_ChangeShape(self, *args)

    def List(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        No available documentation.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeListOfShape_List(self, *args)

    def Shape(self, *args) -> "TopoDS_Shape const":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Shape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeListOfShape_Shape(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_ShapeListOfShape

# Register TopOpeBRepBuild_ShapeListOfShape in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_ShapeListOfShape_swigregister(TopOpeBRepBuild_ShapeListOfShape)

class TopOpeBRepBuild_ShapeSet(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a shapeset in order to build shapes connected by <subshapetype> shapes. <checkshape>:check (or not) the shapes, startelements, elements added.

        Parameters
        ----------
        SubShapeType: TopAbs_ShapeEnum
        checkshape: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_ShapeSet(*args))

    def AddElement(self, *args) -> "void":
        r"""
        For each subshape se of s of type mysubshapetype - add subshapes of s to the map of subshapes (mysubshapemap) - add s to the list of shape incident to subshapes of s.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_AddElement(self, *args)

    def AddShape(self, *args) -> "void":
        r"""
        Adds <s> to the list of shapes. (wires or shells).

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_AddShape(self, *args)

    def AddStartElement(self, *args) -> "void":
        r"""
        (s is a face or edge) add s to the list of starting shapes used for reconstructions. apply addelement(s).

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_AddStartElement(self, *args)

    def ChangeStartShapes(self, *args) -> "TopTools_ListOfShape &":
        r"""
        No available documentation.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_ChangeStartShapes(self, *args)

    def CheckShape(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        checkshape: bool

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        checkgeom: bool,optional
        	default value is Standard_False

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_CheckShape(self, *args)

    def DEBName(self, *args) -> "TCollection_AsciiString const &":
        r"""
        No available documentation.

        Parameters
        ----------
        N: TCollection_AsciiString

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        TCollection_AsciiString

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_DEBName(self, *args)

    def DEBNumber(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        I: int

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_DEBNumber(self, *args)

    def DumpBB(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_DumpBB(self, *args)

    def DumpSS(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_DumpSS(self, *args)

    def FindNeighbours(self, *args) -> "void":
        r"""
        Build the list of neighbour shapes of mycurrentshape (neighbour shapes and mycurrentshapes are of type t) initialize myincidentshapesiter on neighbour shapes.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_FindNeighbours(self, *args)

    def InitNeighbours(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_InitNeighbours(self, *args)

    def InitShapes(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_InitShapes(self, *args)

    def InitStartElements(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_InitStartElements(self, *args)

    def MakeNeighboursList(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Shape
        V: TopoDS_Shape

        Returns
        -------
        TopTools_ListOfShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_MakeNeighboursList(self, *args)

    def MaxNumberSubShape(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        Shape: TopoDS_Shape

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_MaxNumberSubShape(self, *args)

    def MoreNeighbours(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_MoreNeighbours(self, *args)

    def MoreShapes(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_MoreShapes(self, *args)

    def MoreStartElements(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_MoreStartElements(self, *args)

    def Neighbour(self, *args) -> "TopoDS_Shape const":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Shape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_Neighbour(self, *args)

    def NextNeighbour(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_NextNeighbour(self, *args)

    def NextShape(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_NextShape(self, *args)

    def NextStartElement(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_NextStartElement(self, *args)

    def SName(self, *args) -> "TCollection_AsciiString":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        sb: TCollection_AsciiString,optional
        	default value is 
        sa: TCollection_AsciiString,optional
        	default value is 

        Returns
        -------
        TCollection_AsciiString
        No available documentation.

        Parameters
        ----------
        S: TopTools_ListOfShape
        sb: TCollection_AsciiString,optional
        	default value is 
        sa: TCollection_AsciiString,optional
        	default value is 

        Returns
        -------
        TCollection_AsciiString

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_SName(self, *args)

    def SNameori(self, *args) -> "TCollection_AsciiString":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        sb: TCollection_AsciiString,optional
        	default value is 
        sa: TCollection_AsciiString,optional
        	default value is 

        Returns
        -------
        TCollection_AsciiString
        No available documentation.

        Parameters
        ----------
        S: TopTools_ListOfShape
        sb: TCollection_AsciiString,optional
        	default value is 
        sa: TCollection_AsciiString,optional
        	default value is 

        Returns
        -------
        TCollection_AsciiString

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_SNameori(self, *args)

    def Shape(self, *args) -> "TopoDS_Shape const":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Shape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_Shape(self, *args)

    def StartElement(self, *args) -> "TopoDS_Shape const":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Shape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_StartElement(self, *args)

    def StartElements(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Return a reference on mystartshapes.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_StartElements(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_ShapeSet

# Register TopOpeBRepBuild_ShapeSet in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_ShapeSet_swigregister(TopOpeBRepBuild_ShapeSet)

class TopOpeBRepBuild_ShellToSolid(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_ShellToSolid_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_ShellToSolid(*args))

    def AddShell(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Sh: TopoDS_Shell

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShellToSolid_AddShell(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShellToSolid_Init(self, *args)

    def MakeSolids(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        So: TopoDS_Solid
        LSo: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShellToSolid_MakeSolids(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_ShellToSolid

# Register TopOpeBRepBuild_ShellToSolid in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_ShellToSolid_swigregister(TopOpeBRepBuild_ShellToSolid)

class TopOpeBRepBuild_SolidBuilder(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        Create a solidbuilder to build the areas on the shapes (shells, blocks of faces) described by <ls>.

        Parameters
        ----------
        FS: TopOpeBRepBuild_ShellFaceSet
        ForceClass: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_SolidBuilder_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_SolidBuilder(*args))

    def Face(self, *args) -> "TopoDS_Shape const":
        r"""
        Returns current new face of current new shell.

        Returns
        -------
        TopoDS_Shape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_SolidBuilder_Face(self, *args)

    def InitFace(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_SolidBuilder_InitFace(self, *args)

    def InitShell(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_SolidBuilder_InitShell(self, *args)

    def InitSolid(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_SolidBuilder_InitSolid(self, *args)

    def InitSolidBuilder(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        FS: TopOpeBRepBuild_ShellFaceSet
        ForceClass: bool

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_SolidBuilder_InitSolidBuilder(self, *args)

    def IsOldShell(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_SolidBuilder_IsOldShell(self, *args)

    def MoreFace(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_SolidBuilder_MoreFace(self, *args)

    def MoreShell(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_SolidBuilder_MoreShell(self, *args)

    def MoreSolid(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_SolidBuilder_MoreSolid(self, *args)

    def NextFace(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_SolidBuilder_NextFace(self, *args)

    def NextShell(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_SolidBuilder_NextShell(self, *args)

    def NextSolid(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_SolidBuilder_NextSolid(self, *args)

    def OldShell(self, *args) -> "TopoDS_Shape const":
        r"""
        Returns current shell this shell may be : * an old shell oldshell(), which has not been reconstructed; * a new shell made of faces described by ...newface() methods.

        Returns
        -------
        TopoDS_Shape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_SolidBuilder_OldShell(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_SolidBuilder

# Register TopOpeBRepBuild_SolidBuilder in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_SolidBuilder_swigregister(TopOpeBRepBuild_SolidBuilder)

class TopOpeBRepBuild_Tools(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def CheckFaceClosed2d(*args) -> "Standard_Boolean":
        r"""
        Checks if <theface> has the properly closed in 2d boundary(ies).

        Parameters
        ----------
        theFace: TopoDS_Face

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_CheckFaceClosed2d(*args)

    @staticmethod
    def CorrectCurveOnSurface(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aS: TopoDS_Shape
        aTolMax: float,optional
        	default value is 0.0001

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_CorrectCurveOnSurface(*args)

    @staticmethod
    def CorrectFace2d(*args) -> "void":
        r"""
        Test if uv representation of <oldface> is good (i.e. face is closed in 2d). if face is not closed , this method will try to close such face and will return corrected edges in the <amapofcorrect2dedges>. parameter <asourceshapes> used to fix the edge (or wires) which should be correct (corrector used it as a start shapes). note : parameter corrface doesn't mean anything. if you want to use this method , rebuild resulting face after by yourself using corrected edges.

        Parameters
        ----------
        oldFace: TopoDS_Shape
        corrFace: TopoDS_Shape
        aSourceShapes: TopTools_IndexedMapOfOrientedShape
        aMapOfCorrect2dEdges: TopTools_IndexedDataMapOfShapeShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_CorrectFace2d(*args)

    @staticmethod
    def CorrectPointOnCurve(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aS: TopoDS_Shape
        aTolMax: float,optional
        	default value is 0.0001

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_CorrectPointOnCurve(*args)

    @staticmethod
    def CorrectTolerances(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aS: TopoDS_Shape
        aTolMax: float,optional
        	default value is 0.0001

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_CorrectTolerances(*args)

    @staticmethod
    def FindState(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aVertex: TopoDS_Shape
        aState: TopAbs_State
        aShapeEnum: TopAbs_ShapeEnum
        aMapVertexEdges: TopTools_IndexedDataMapOfShapeListOfShape
        aMapProcessedVertices: TopTools_MapOfShape
        aMapVs: TopOpeBRepDS_DataMapOfShapeState

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_FindState(*args)

    @staticmethod
    def FindState1(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        anEdge: TopoDS_Shape
        aState: TopAbs_State
        aMapEdgesFaces: TopTools_IndexedDataMapOfShapeListOfShape
        aMapProcessedVertices: TopTools_MapOfShape
        aMapVs: TopOpeBRepDS_DataMapOfShapeState

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_FindState1(*args)

    @staticmethod
    def FindState2(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        anEdge: TopoDS_Shape
        aState: TopAbs_State
        aMapEdgesFaces: TopTools_IndexedDataMapOfShapeListOfShape
        aMapProcessedEdges: TopTools_MapOfShape
        aMapVs: TopOpeBRepDS_DataMapOfShapeState

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_FindState2(*args)

    @staticmethod
    def FindStateThroughVertex(*args) -> "TopAbs_State":
        r"""
        No available documentation.

        Parameters
        ----------
        aShape: TopoDS_Shape
        aShapeClassifier: TopOpeBRepTool_ShapeClassifier
        aMapOfShapeWithState: TopOpeBRepDS_IndexedDataMapOfShapeWithState
        anAvoidSubshMap: TopTools_MapOfShape

        Returns
        -------
        TopAbs_State

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_FindStateThroughVertex(*args)

    @staticmethod
    def GetAdjacentFace(*args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        aFaceObj: TopoDS_Shape
        anEObj: TopoDS_Shape
        anEdgeFaceMap: TopTools_IndexedDataMapOfShapeListOfShape
        anAdjFaceObj: TopoDS_Shape

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_GetAdjacentFace(*args)

    @staticmethod
    def GetNormalInNearestPoint(*args) -> "void":
        r"""
        This function used to compute normal in point which is located near the point with param uv (used for computation of normals where the normal in the point uv equal to zero).

        Parameters
        ----------
        aFace: TopoDS_Face
        anEdge: TopoDS_Edge
        aNormal: gp_Vec

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_GetNormalInNearestPoint(*args)

    @staticmethod
    def GetNormalToFaceOnEdge(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aFObj: TopoDS_Face
        anEdgeObj: TopoDS_Edge
        aDirNormal: gp_Vec

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_GetNormalToFaceOnEdge(*args)

    @staticmethod
    def GetTangentToEdge(*args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        anEdgeObj: TopoDS_Edge
        aTangent: gp_Vec

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_GetTangentToEdge(*args)

    @staticmethod
    def GetTangentToEdgeEdge(*args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        aFObj: TopoDS_Face
        anEdgeObj: TopoDS_Edge
        aOriEObj: TopoDS_Edge
        aTangent: gp_Vec

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_GetTangentToEdgeEdge(*args)

    @staticmethod
    def IsDegEdgesTheSame(*args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        anE1: TopoDS_Shape
        anE2: TopoDS_Shape

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_IsDegEdgesTheSame(*args)

    @staticmethod
    def NormalizeFace(*args) -> "void":
        r"""
        Test if <oldface> does not contain internal or external edges and remove such edges in case of its presence. the result is stored in <corrface>.

        Parameters
        ----------
        oldFace: TopoDS_Shape
        corrFace: TopoDS_Shape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_NormalizeFace(*args)

    @staticmethod
    def PropagateState(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aSplEdgesState: TopOpeBRepDS_DataMapOfShapeState
        anEdgesToRestMap: TopTools_IndexedMapOfShape
        aShapeEnum1: TopAbs_ShapeEnum
        aShapeEnum2: TopAbs_ShapeEnum
        aShapeClassifier: TopOpeBRepTool_ShapeClassifier
        aMapOfShapeWithState: TopOpeBRepDS_IndexedDataMapOfShapeWithState
        anUnkStateShapes: TopTools_MapOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_PropagateState(*args)

    @staticmethod
    def PropagateStateForWires(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aFacesToRestMap: TopTools_IndexedMapOfShape
        aMapOfShapeWithState: TopOpeBRepDS_IndexedDataMapOfShapeWithState

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_PropagateStateForWires(*args)

    @staticmethod
    def SpreadStateToChild(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aShape: TopoDS_Shape
        aState: TopAbs_State
        aMapOfShapeWithState: TopOpeBRepDS_IndexedDataMapOfShapeWithState

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_SpreadStateToChild(*args)

    @staticmethod
    def UpdateEdgeOnFace(*args) -> "void":
        r"""
        Recompute pcurve of the edge on the newface.

        Parameters
        ----------
        aEdgeToUpdate: TopoDS_Edge
        OldFace: TopoDS_Face
        NewFace: TopoDS_Face

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_UpdateEdgeOnFace(*args)

    @staticmethod
    def UpdateEdgeOnPeriodicalFace(*args) -> "void":
        r"""
        Recompute pcurves of the closing (sim , with 2 pcurves) edge on the newface.

        Parameters
        ----------
        aEdgeToUpdate: TopoDS_Edge
        OldFace: TopoDS_Face
        NewFace: TopoDS_Face

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_UpdateEdgeOnPeriodicalFace(*args)

    @staticmethod
    def UpdatePCurves(*args) -> "void":
        r"""
        Recompute pcurves of the all edges from the wire on the <toface>.

        Parameters
        ----------
        aWire: TopoDS_Wire
        fromFace: TopoDS_Face
        toFace: TopoDS_Face

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_UpdatePCurves(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _TopOpeBRepBuild.TopOpeBRepBuild_Tools_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_Tools())
    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_Tools

# Register TopOpeBRepBuild_Tools in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_Tools_swigregister(TopOpeBRepBuild_Tools)

def TopOpeBRepBuild_Tools_CheckFaceClosed2d(*args) -> "Standard_Boolean":
    r"""
    Checks if <theface> has the properly closed in 2d boundary(ies).

    Parameters
    ----------
    theFace: TopoDS_Face

    Returns
    -------
    bool

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_CheckFaceClosed2d(*args)

def TopOpeBRepBuild_Tools_CorrectCurveOnSurface(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aS: TopoDS_Shape
    aTolMax: float,optional
    	default value is 0.0001

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_CorrectCurveOnSurface(*args)

def TopOpeBRepBuild_Tools_CorrectFace2d(*args) -> "void":
    r"""
    Test if uv representation of <oldface> is good (i.e. face is closed in 2d). if face is not closed , this method will try to close such face and will return corrected edges in the <amapofcorrect2dedges>. parameter <asourceshapes> used to fix the edge (or wires) which should be correct (corrector used it as a start shapes). note : parameter corrface doesn't mean anything. if you want to use this method , rebuild resulting face after by yourself using corrected edges.

    Parameters
    ----------
    oldFace: TopoDS_Shape
    corrFace: TopoDS_Shape
    aSourceShapes: TopTools_IndexedMapOfOrientedShape
    aMapOfCorrect2dEdges: TopTools_IndexedDataMapOfShapeShape

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_CorrectFace2d(*args)

def TopOpeBRepBuild_Tools_CorrectPointOnCurve(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aS: TopoDS_Shape
    aTolMax: float,optional
    	default value is 0.0001

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_CorrectPointOnCurve(*args)

def TopOpeBRepBuild_Tools_CorrectTolerances(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aS: TopoDS_Shape
    aTolMax: float,optional
    	default value is 0.0001

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_CorrectTolerances(*args)

def TopOpeBRepBuild_Tools_FindState(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aVertex: TopoDS_Shape
    aState: TopAbs_State
    aShapeEnum: TopAbs_ShapeEnum
    aMapVertexEdges: TopTools_IndexedDataMapOfShapeListOfShape
    aMapProcessedVertices: TopTools_MapOfShape
    aMapVs: TopOpeBRepDS_DataMapOfShapeState

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_FindState(*args)

def TopOpeBRepBuild_Tools_FindState1(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    anEdge: TopoDS_Shape
    aState: TopAbs_State
    aMapEdgesFaces: TopTools_IndexedDataMapOfShapeListOfShape
    aMapProcessedVertices: TopTools_MapOfShape
    aMapVs: TopOpeBRepDS_DataMapOfShapeState

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_FindState1(*args)

def TopOpeBRepBuild_Tools_FindState2(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    anEdge: TopoDS_Shape
    aState: TopAbs_State
    aMapEdgesFaces: TopTools_IndexedDataMapOfShapeListOfShape
    aMapProcessedEdges: TopTools_MapOfShape
    aMapVs: TopOpeBRepDS_DataMapOfShapeState

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_FindState2(*args)

def TopOpeBRepBuild_Tools_FindStateThroughVertex(*args) -> "TopAbs_State":
    r"""
    No available documentation.

    Parameters
    ----------
    aShape: TopoDS_Shape
    aShapeClassifier: TopOpeBRepTool_ShapeClassifier
    aMapOfShapeWithState: TopOpeBRepDS_IndexedDataMapOfShapeWithState
    anAvoidSubshMap: TopTools_MapOfShape

    Returns
    -------
    TopAbs_State

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_FindStateThroughVertex(*args)

def TopOpeBRepBuild_Tools_GetAdjacentFace(*args) -> "Standard_Boolean":
    r"""
    No available documentation.

    Parameters
    ----------
    aFaceObj: TopoDS_Shape
    anEObj: TopoDS_Shape
    anEdgeFaceMap: TopTools_IndexedDataMapOfShapeListOfShape
    anAdjFaceObj: TopoDS_Shape

    Returns
    -------
    bool

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_GetAdjacentFace(*args)

def TopOpeBRepBuild_Tools_GetNormalInNearestPoint(*args) -> "void":
    r"""
    This function used to compute normal in point which is located near the point with param uv (used for computation of normals where the normal in the point uv equal to zero).

    Parameters
    ----------
    aFace: TopoDS_Face
    anEdge: TopoDS_Edge
    aNormal: gp_Vec

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_GetNormalInNearestPoint(*args)

def TopOpeBRepBuild_Tools_GetNormalToFaceOnEdge(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aFObj: TopoDS_Face
    anEdgeObj: TopoDS_Edge
    aDirNormal: gp_Vec

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_GetNormalToFaceOnEdge(*args)

def TopOpeBRepBuild_Tools_GetTangentToEdge(*args) -> "Standard_Boolean":
    r"""
    No available documentation.

    Parameters
    ----------
    anEdgeObj: TopoDS_Edge
    aTangent: gp_Vec

    Returns
    -------
    bool

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_GetTangentToEdge(*args)

def TopOpeBRepBuild_Tools_GetTangentToEdgeEdge(*args) -> "Standard_Boolean":
    r"""
    No available documentation.

    Parameters
    ----------
    aFObj: TopoDS_Face
    anEdgeObj: TopoDS_Edge
    aOriEObj: TopoDS_Edge
    aTangent: gp_Vec

    Returns
    -------
    bool

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_GetTangentToEdgeEdge(*args)

def TopOpeBRepBuild_Tools_IsDegEdgesTheSame(*args) -> "Standard_Boolean":
    r"""
    No available documentation.

    Parameters
    ----------
    anE1: TopoDS_Shape
    anE2: TopoDS_Shape

    Returns
    -------
    bool

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_IsDegEdgesTheSame(*args)

def TopOpeBRepBuild_Tools_NormalizeFace(*args) -> "void":
    r"""
    Test if <oldface> does not contain internal or external edges and remove such edges in case of its presence. the result is stored in <corrface>.

    Parameters
    ----------
    oldFace: TopoDS_Shape
    corrFace: TopoDS_Shape

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_NormalizeFace(*args)

def TopOpeBRepBuild_Tools_PropagateState(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aSplEdgesState: TopOpeBRepDS_DataMapOfShapeState
    anEdgesToRestMap: TopTools_IndexedMapOfShape
    aShapeEnum1: TopAbs_ShapeEnum
    aShapeEnum2: TopAbs_ShapeEnum
    aShapeClassifier: TopOpeBRepTool_ShapeClassifier
    aMapOfShapeWithState: TopOpeBRepDS_IndexedDataMapOfShapeWithState
    anUnkStateShapes: TopTools_MapOfShape

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_PropagateState(*args)

def TopOpeBRepBuild_Tools_PropagateStateForWires(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aFacesToRestMap: TopTools_IndexedMapOfShape
    aMapOfShapeWithState: TopOpeBRepDS_IndexedDataMapOfShapeWithState

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_PropagateStateForWires(*args)

def TopOpeBRepBuild_Tools_SpreadStateToChild(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aShape: TopoDS_Shape
    aState: TopAbs_State
    aMapOfShapeWithState: TopOpeBRepDS_IndexedDataMapOfShapeWithState

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_SpreadStateToChild(*args)

def TopOpeBRepBuild_Tools_UpdateEdgeOnFace(*args) -> "void":
    r"""
    Recompute pcurve of the edge on the newface.

    Parameters
    ----------
    aEdgeToUpdate: TopoDS_Edge
    OldFace: TopoDS_Face
    NewFace: TopoDS_Face

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_UpdateEdgeOnFace(*args)

def TopOpeBRepBuild_Tools_UpdateEdgeOnPeriodicalFace(*args) -> "void":
    r"""
    Recompute pcurves of the closing (sim , with 2 pcurves) edge on the newface.

    Parameters
    ----------
    aEdgeToUpdate: TopoDS_Edge
    OldFace: TopoDS_Face
    NewFace: TopoDS_Face

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_UpdateEdgeOnPeriodicalFace(*args)

def TopOpeBRepBuild_Tools_UpdatePCurves(*args) -> "void":
    r"""
    Recompute pcurves of the all edges from the wire on the <toface>.

    Parameters
    ----------
    aWire: TopoDS_Wire
    fromFace: TopoDS_Face
    toFace: TopoDS_Face

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Tools_UpdatePCurves(*args)

class TopOpeBRepBuild_Tools2d(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def DumpMapOfShapeVertexInfo(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aMap: TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Tools2d_DumpMapOfShapeVertexInfo(*args)

    @staticmethod
    def MakeMapOfShapeVertexInfo(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aWire: TopoDS_Wire
        aMap: TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Tools2d_MakeMapOfShapeVertexInfo(*args)

    @staticmethod
    def Path(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aWire: TopoDS_Wire
        aResList: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Tools2d_Path(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _TopOpeBRepBuild.TopOpeBRepBuild_Tools2d_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_Tools2d())
    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_Tools2d

# Register TopOpeBRepBuild_Tools2d in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_Tools2d_swigregister(TopOpeBRepBuild_Tools2d)

def TopOpeBRepBuild_Tools2d_DumpMapOfShapeVertexInfo(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aMap: TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Tools2d_DumpMapOfShapeVertexInfo(*args)

def TopOpeBRepBuild_Tools2d_MakeMapOfShapeVertexInfo(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aWire: TopoDS_Wire
    aMap: TopOpeBRepBuild_IndexedDataMapOfShapeVertexInfo

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Tools2d_MakeMapOfShapeVertexInfo(*args)

def TopOpeBRepBuild_Tools2d_Path(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aWire: TopoDS_Wire
    aResList: TopTools_ListOfShape

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Tools2d_Path(*args)

class TopOpeBRepBuild_VertexInfo(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_VertexInfo_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_VertexInfo(*args))

    def AddIn(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        anE: TopoDS_Edge

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_VertexInfo_AddIn(self, *args)

    def AddOut(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        anE: TopoDS_Edge

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_VertexInfo_AddOut(self, *args)

    def AppendPassed(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        anE: TopoDS_Edge

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_VertexInfo_AppendPassed(self, *args)

    def ChangeEdgesOut(self, *args) -> "TopTools_IndexedMapOfOrientedShape &":
        r"""
        No available documentation.

        Returns
        -------
        TopTools_IndexedMapOfOrientedShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_VertexInfo_ChangeEdgesOut(self, *args)

    def CurrentOut(self, *args) -> "TopoDS_Edge const":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Edge

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_VertexInfo_CurrentOut(self, *args)

    def Dump(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_VertexInfo_Dump(self, *args)

    def EdgesIn(self, *args) -> "TopTools_IndexedMapOfOrientedShape const &":
        r"""
        No available documentation.

        Returns
        -------
        TopTools_IndexedMapOfOrientedShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_VertexInfo_EdgesIn(self, *args)

    def EdgesOut(self, *args) -> "TopTools_IndexedMapOfOrientedShape const &":
        r"""
        No available documentation.

        Returns
        -------
        TopTools_IndexedMapOfOrientedShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_VertexInfo_EdgesOut(self, *args)

    def FoundOut(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_VertexInfo_FoundOut(self, *args)

    def ListPassed(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        No available documentation.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_VertexInfo_ListPassed(self, *args)

    def NbCases(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_VertexInfo_NbCases(self, *args)

    def Prepare(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aL: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_VertexInfo_Prepare(self, *args)

    def RemovePassed(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_VertexInfo_RemovePassed(self, *args)

    def SetCurrentIn(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        anE: TopoDS_Edge

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_VertexInfo_SetCurrentIn(self, *args)

    def SetSmart(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aFlag: bool

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_VertexInfo_SetSmart(self, *args)

    def SetVertex(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aV: TopoDS_Vertex

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_VertexInfo_SetVertex(self, *args)

    def Smart(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_VertexInfo_Smart(self, *args)

    def Vertex(self, *args) -> "TopoDS_Vertex const":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Vertex

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_VertexInfo_Vertex(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_VertexInfo

# Register TopOpeBRepBuild_VertexInfo in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_VertexInfo_swigregister(TopOpeBRepBuild_VertexInfo)

class TopOpeBRepBuild_WireToFace(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_WireToFace_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_WireToFace(*args))

    def AddWire(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        W: TopoDS_Wire

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_WireToFace_AddWire(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_WireToFace_Init(self, *args)

    def MakeFaces(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face
        LF: TopTools_ListOfShape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_WireToFace_MakeFaces(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_WireToFace

# Register TopOpeBRepBuild_WireToFace in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_WireToFace_swigregister(TopOpeBRepBuild_WireToFace)

class TopOpeBRepBuild_Area1dBuilder(TopOpeBRepBuild_AreaBuilder):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        Creates a area1dbuilder to find the areas of the shapes described by <ls> using the classifier <lc>.

        Parameters
        ----------
        LS: TopOpeBRepBuild_PaveSet
        LC: TopOpeBRepBuild_PaveClassifier
        ForceClass: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_Area1dBuilder_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_Area1dBuilder(*args))

    @staticmethod
    def DumpList(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        L: TopOpeBRepBuild_ListOfLoop

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Area1dBuilder_DumpList(*args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_Area1dBuilder

# Register TopOpeBRepBuild_Area1dBuilder in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_Area1dBuilder_swigregister(TopOpeBRepBuild_Area1dBuilder)

def TopOpeBRepBuild_Area1dBuilder_DumpList(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    L: TopOpeBRepBuild_ListOfLoop

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_Area1dBuilder_DumpList(*args)

class TopOpeBRepBuild_Area2dBuilder(TopOpeBRepBuild_AreaBuilder):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        Creates a area2dbuilder to build faces on the (wires,blocks of edge) of <ls>, using the classifier <lc>.

        Parameters
        ----------
        LS: TopOpeBRepBuild_LoopSet
        LC: TopOpeBRepBuild_LoopClassifier
        ForceClass: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_Area2dBuilder_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_Area2dBuilder(*args))

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_Area2dBuilder

# Register TopOpeBRepBuild_Area2dBuilder in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_Area2dBuilder_swigregister(TopOpeBRepBuild_Area2dBuilder)

class TopOpeBRepBuild_Area3dBuilder(TopOpeBRepBuild_AreaBuilder):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        Creates a area3dbuilder to build solids on the (shells,blocks of face) of <ls>, using the classifier <lc>.

        Parameters
        ----------
        LS: TopOpeBRepBuild_LoopSet
        LC: TopOpeBRepBuild_LoopClassifier
        ForceClass: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_Area3dBuilder_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_Area3dBuilder(*args))

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_Area3dBuilder

# Register TopOpeBRepBuild_Area3dBuilder in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_Area3dBuilder_swigregister(TopOpeBRepBuild_Area3dBuilder)

class TopOpeBRepBuild_Builder1(TopOpeBRepBuild_Builder):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        BT: TopOpeBRepDS_BuildTool

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_Builder1_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_Builder1(*args))

    def CorrectResult2d(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        aResult: TopoDS_Shape

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder1_CorrectResult2d(self, *args)

    def GFillEdgeNotSameDomWES(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        E1: TopoDS_Shape
        LSO2: TopTools_ListOfShape
        G: TopOpeBRepBuild_GTopo
        WES: TopOpeBRepBuild_WireEdgeSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder1_GFillEdgeNotSameDomWES(self, *args)

    def GFillEdgeSameDomWES(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        E1: TopoDS_Shape
        LSO2: TopTools_ListOfShape
        G: TopOpeBRepBuild_GTopo
        WES: TopOpeBRepBuild_WireEdgeSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder1_GFillEdgeSameDomWES(self, *args)

    def GFillFaceNotSameDomSFS(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        F1: TopoDS_Shape
        LSO2: TopTools_ListOfShape
        G: TopOpeBRepBuild_GTopo
        SFS: TopOpeBRepBuild_ShellFaceSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder1_GFillFaceNotSameDomSFS(self, *args)

    def GFillFaceNotSameDomWES(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        F1: TopoDS_Shape
        LSO2: TopTools_ListOfShape
        G: TopOpeBRepBuild_GTopo
        WES: TopOpeBRepBuild_WireEdgeSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder1_GFillFaceNotSameDomWES(self, *args)

    def GFillFaceSameDomSFS(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        F1: TopoDS_Shape
        LSO2: TopTools_ListOfShape
        G: TopOpeBRepBuild_GTopo
        SFS: TopOpeBRepBuild_ShellFaceSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder1_GFillFaceSameDomSFS(self, *args)

    def GFillFaceSameDomWES(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        F1: TopoDS_Shape
        LSO2: TopTools_ListOfShape
        G: TopOpeBRepBuild_GTopo
        WES: TopOpeBRepBuild_WireEdgeSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder1_GFillFaceSameDomWES(self, *args)

    def GFillWireNotSameDomWES(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        W1: TopoDS_Shape
        LSO2: TopTools_ListOfShape
        G: TopOpeBRepBuild_GTopo
        WES: TopOpeBRepBuild_WireEdgeSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder1_GFillWireNotSameDomWES(self, *args)

    def GFillWireSameDomWES(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        W1: TopoDS_Shape
        LSO2: TopTools_ListOfShape
        G: TopOpeBRepBuild_GTopo
        WES: TopOpeBRepBuild_WireEdgeSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder1_GFillWireSameDomWES(self, *args)

    def MergeKPart(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        TB1: TopAbs_State
        TB2: TopAbs_State

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder1_MergeKPart(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        HDS: TopOpeBRepDS_HDataStructure

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        HDS: TopOpeBRepDS_HDataStructure
        S1: TopoDS_Shape
        S2: TopoDS_Shape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder1_Perform(self, *args)

    def PerformONParts(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Shape
        SDfaces: TopTools_IndexedMapOfShape
        G: TopOpeBRepBuild_GTopo
        WES: TopOpeBRepBuild_WireEdgeSet

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder1_PerformONParts(self, *args)

    def PerformPieceIn2D(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aPieceToPerform: TopoDS_Edge
        aOriginalEdge: TopoDS_Edge
        edgeFace: TopoDS_Face
        toFace: TopoDS_Face
        G: TopOpeBRepBuild_GTopo

        Returns
        -------
        keep: bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder1_PerformPieceIn2D(self, *args)

    def PerformPieceOn2D(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        aPieceObj: TopoDS_Shape
        aFaceObj: TopoDS_Shape
        aEdgeObj: TopoDS_Shape
        aListOfPieces: TopTools_ListOfShape
        aListOfFaces: TopTools_ListOfShape
        aListOfPiecesOut2d: TopTools_ListOfShape

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder1_PerformPieceOn2D(self, *args)

    def TwoPiecesON(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        aSeq: TopTools_SequenceOfShape
        aListOfPieces: TopTools_ListOfShape
        aListOfFaces: TopTools_ListOfShape
        aListOfPiecesOut2d: TopTools_ListOfShape

        Returns
        -------
        int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Builder1_TwoPiecesON(self, *args)

    __repr__ = _dumps_object

    @methodnotwrapped
    def GFillSplitsPVS(self):
    	pass

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_Builder1

# Register TopOpeBRepBuild_Builder1 in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_Builder1_swigregister(TopOpeBRepBuild_Builder1)

class TopOpeBRepBuild_CompositeClassifier(TopOpeBRepBuild_LoopClassifier):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def CompareElement(self, *args) -> "Standard_Boolean":
        r"""
        Add element <e> in the set of elements used in classification. returns false if the element <e> has been already added to the set of elements, otherwise returns true.

        Parameters
        ----------
        E: TopoDS_Shape

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_CompositeClassifier_CompareElement(self, *args)

    def CompareElementToShape(self, *args) -> "TopAbs_State":
        r"""
        Classify element <e> with shape <b>.

        Parameters
        ----------
        E: TopoDS_Shape
        B: TopoDS_Shape

        Returns
        -------
        TopAbs_State

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_CompositeClassifier_CompareElementToShape(self, *args)

    def CompareShapes(self, *args) -> "TopAbs_State":
        r"""
        Classify shape <b1> with shape <b2>.

        Parameters
        ----------
        B1: TopoDS_Shape
        B2: TopoDS_Shape

        Returns
        -------
        TopAbs_State

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_CompositeClassifier_CompareShapes(self, *args)

    def ResetElement(self, *args) -> "void":
        r"""
        Prepare classification involving element <e>.

        Parameters
        ----------
        E: TopoDS_Shape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_CompositeClassifier_ResetElement(self, *args)

    def ResetShape(self, *args) -> "void":
        r"""
        Prepare classification involving shape <b> calls resetelement on first element of <b>.

        Parameters
        ----------
        B: TopoDS_Shape

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_CompositeClassifier_ResetShape(self, *args)

    def State(self, *args) -> "TopAbs_State":
        r"""
        Returns state of classification of 2d point, defined by resetelement, with the current set of elements, defined by compare.

        Returns
        -------
        TopAbs_State

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_CompositeClassifier_State(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_CompositeClassifier

# Register TopOpeBRepBuild_CompositeClassifier in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_CompositeClassifier_swigregister(TopOpeBRepBuild_CompositeClassifier)

class TopOpeBRepBuild_Pave(TopOpeBRepBuild_Loop):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        V = vertex, p = parameter of vertex <v> bound = true if <v> is an old vertex bound = false if <v> is a new vertex.

        Parameters
        ----------
        V: TopoDS_Shape
        P: float
        bound: bool

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_Pave_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_Pave(*args))

    def ChangeVertex(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Shape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Pave_ChangeVertex(self, *args)

    def HasSameDomain(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        b: bool

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Pave_HasSameDomain(self, *args)

    def InterferenceType(self, *args) -> "TopOpeBRepDS_Kind &":
        r"""
        No available documentation.

        Returns
        -------
        TopOpeBRepDS_Kind

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Pave_InterferenceType(self, *args)

    def Parameter(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        float
        No available documentation.

        Parameters
        ----------
        Par: float

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Pave_Parameter(self, *args)

    def SameDomain(self, *args) -> "TopoDS_Shape const":
        r"""
        No available documentation.

        Parameters
        ----------
        VSD: TopoDS_Shape

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        TopoDS_Shape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Pave_SameDomain(self, *args)

    def Vertex(self, *args) -> "TopoDS_Shape const":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Shape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_Pave_Vertex(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_TopOpeBRepBuild_Pave_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_Pave

# Register TopOpeBRepBuild_Pave in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_Pave_swigregister(TopOpeBRepBuild_Pave)

class TopOpeBRepBuild_PaveClassifier(TopOpeBRepBuild_LoopClassifier):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Create a pave classifier to compare vertices on edge <e>.

        Parameters
        ----------
        E: TopoDS_Shape

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_PaveClassifier_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_PaveClassifier(*args))

    @staticmethod
    def AdjustCase(*args) -> "Standard_Integer &":
        r"""
        No available documentation.

        Parameters
        ----------
        p1: float
        o: TopAbs_Orientation
        first: float
        period: float
        tol: float

        Returns
        -------
        cas: int

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_PaveClassifier_AdjustCase(*args)

    def ClosedVertices(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        B: bool

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_PaveClassifier_ClosedVertices(self, *args)

    def SetFirstParameter(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        P: float

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_PaveClassifier_SetFirstParameter(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_PaveClassifier

# Register TopOpeBRepBuild_PaveClassifier in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_PaveClassifier_swigregister(TopOpeBRepBuild_PaveClassifier)

def TopOpeBRepBuild_PaveClassifier_AdjustCase(*args) -> "Standard_Integer &":
    r"""
    No available documentation.

    Parameters
    ----------
    p1: float
    o: TopAbs_Orientation
    first: float
    period: float
    tol: float

    Returns
    -------
    cas: int

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_PaveClassifier_AdjustCase(*args)

class TopOpeBRepBuild_PaveSet(TopOpeBRepBuild_LoopSet):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Create a pave set on edge <e>. it contains <e> vertices.

        Parameters
        ----------
        E: TopoDS_Shape

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_PaveSet_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_PaveSet(*args))

    def Append(self, *args) -> "void":
        r"""
        Add <pv> in the pave set.

        Parameters
        ----------
        PV: TopOpeBRepBuild_Pave

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_PaveSet_Append(self, *args)

    def ClosedVertices(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_PaveSet_ClosedVertices(self, *args)

    def Edge(self, *args) -> "TopoDS_Edge const":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Edge

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_PaveSet_Edge(self, *args)

    def EqualParameters(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_PaveSet_EqualParameters(self, *args)

    def HasEqualParameters(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_PaveSet_HasEqualParameters(self, *args)

    def RemovePV(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        B: bool

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_PaveSet_RemovePV(self, *args)

    @staticmethod
    def SortPave(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Lin: TopOpeBRepBuild_ListOfPave
        Lout: TopOpeBRepBuild_ListOfPave

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_PaveSet_SortPave(*args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_PaveSet

# Register TopOpeBRepBuild_PaveSet in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_PaveSet_swigregister(TopOpeBRepBuild_PaveSet)

def TopOpeBRepBuild_PaveSet_SortPave(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    Lin: TopOpeBRepBuild_ListOfPave
    Lout: TopOpeBRepBuild_ListOfPave

    Returns
    -------
    None

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_PaveSet_SortPave(*args)

class TopOpeBRepBuild_ShellFaceSet(TopOpeBRepBuild_ShapeSet):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a shellfaceset to build blocks of faces connected by edges.

        Returns
        -------
        None
        Creates a shellfaceset to build blocks of faces connected by edges.

        Parameters
        ----------
        S: TopoDS_Shape
        Addr: Standard_Address,optional
        	default value is NULL

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_ShellFaceSet_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_ShellFaceSet(*args))

    def SName(self, *args) -> "TCollection_AsciiString":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        sb: TCollection_AsciiString,optional
        	default value is 
        sa: TCollection_AsciiString,optional
        	default value is 

        Returns
        -------
        TCollection_AsciiString
        No available documentation.

        Parameters
        ----------
        S: TopTools_ListOfShape
        sb: TCollection_AsciiString,optional
        	default value is 
        sa: TCollection_AsciiString,optional
        	default value is 

        Returns
        -------
        TCollection_AsciiString

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShellFaceSet_SName(self, *args)

    def SNameori(self, *args) -> "TCollection_AsciiString":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        sb: TCollection_AsciiString,optional
        	default value is 
        sa: TCollection_AsciiString,optional
        	default value is 

        Returns
        -------
        TCollection_AsciiString
        No available documentation.

        Parameters
        ----------
        S: TopTools_ListOfShape
        sb: TCollection_AsciiString,optional
        	default value is 
        sa: TCollection_AsciiString,optional
        	default value is 

        Returns
        -------
        TCollection_AsciiString

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShellFaceSet_SNameori(self, *args)

    def Solid(self, *args) -> "TopoDS_Solid const":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Solid

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShellFaceSet_Solid(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_ShellFaceSet

# Register TopOpeBRepBuild_ShellFaceSet in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_ShellFaceSet_swigregister(TopOpeBRepBuild_ShellFaceSet)

class TopOpeBRepBuild_WireEdgeSet(TopOpeBRepBuild_ShapeSet):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a wireedgeset to build edges connected by vertices on face f. edges of the wireedgeset must have a representation on surface of face f.

        Parameters
        ----------
        F: TopoDS_Shape
        Addr: Standard_Address,optional
        	default value is NULL

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_WireEdgeSet_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_WireEdgeSet(*args))

    def Face(self, *args) -> "TopoDS_Face const":
        r"""
        Value of field myface.

        Returns
        -------
        TopoDS_Face

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_WireEdgeSet_Face(self, *args)

    @staticmethod
    def IsUVISO(*args) -> "Standard_Boolean &, Standard_Boolean &":
        r"""
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Edge
        F: TopoDS_Face

        Returns
        -------
        uiso: bool
        viso: bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_WireEdgeSet_IsUVISO(*args)

    def SName(self, *args) -> "TCollection_AsciiString":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        sb: TCollection_AsciiString,optional
        	default value is 
        sa: TCollection_AsciiString,optional
        	default value is 

        Returns
        -------
        TCollection_AsciiString
        No available documentation.

        Parameters
        ----------
        S: TopTools_ListOfShape
        sb: TCollection_AsciiString,optional
        	default value is 
        sa: TCollection_AsciiString,optional
        	default value is 

        Returns
        -------
        TCollection_AsciiString

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_WireEdgeSet_SName(self, *args)

    def SNameori(self, *args) -> "TCollection_AsciiString":
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        sb: TCollection_AsciiString,optional
        	default value is 
        sa: TCollection_AsciiString,optional
        	default value is 

        Returns
        -------
        TCollection_AsciiString
        No available documentation.

        Parameters
        ----------
        S: TopTools_ListOfShape
        sb: TCollection_AsciiString,optional
        	default value is 
        sa: TCollection_AsciiString,optional
        	default value is 

        Returns
        -------
        TCollection_AsciiString

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_WireEdgeSet_SNameori(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_WireEdgeSet

# Register TopOpeBRepBuild_WireEdgeSet in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_WireEdgeSet_swigregister(TopOpeBRepBuild_WireEdgeSet)

def TopOpeBRepBuild_WireEdgeSet_IsUVISO(*args) -> "Standard_Boolean &, Standard_Boolean &":
    r"""
    No available documentation.

    Parameters
    ----------
    E: TopoDS_Edge
    F: TopoDS_Face

    Returns
    -------
    uiso: bool
    viso: bool

    """
    return _TopOpeBRepBuild.TopOpeBRepBuild_WireEdgeSet_IsUVISO(*args)

class TopOpeBRepBuild_EdgeBuilder(TopOpeBRepBuild_Area1dBuilder):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        Creates a edgebuilder to find the areas of the shapes described by <ls> using the classifier <lc>.

        Parameters
        ----------
        LS: TopOpeBRepBuild_PaveSet
        LC: TopOpeBRepBuild_PaveClassifier
        ForceClass: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_EdgeBuilder_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_EdgeBuilder(*args))

    def InitEdge(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_EdgeBuilder_InitEdge(self, *args)

    def InitEdgeBuilder(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        LS: TopOpeBRepBuild_LoopSet
        LC: TopOpeBRepBuild_LoopClassifier
        ForceClass: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_EdgeBuilder_InitEdgeBuilder(self, *args)

    def InitVertex(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_EdgeBuilder_InitVertex(self, *args)

    def MoreEdge(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_EdgeBuilder_MoreEdge(self, *args)

    def MoreVertex(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_EdgeBuilder_MoreVertex(self, *args)

    def NextEdge(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_EdgeBuilder_NextEdge(self, *args)

    def NextVertex(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_EdgeBuilder_NextVertex(self, *args)

    def Parameter(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_EdgeBuilder_Parameter(self, *args)

    def Vertex(self, *args) -> "TopoDS_Shape const":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Shape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_EdgeBuilder_Vertex(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_EdgeBuilder

# Register TopOpeBRepBuild_EdgeBuilder in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_EdgeBuilder_swigregister(TopOpeBRepBuild_EdgeBuilder)

class TopOpeBRepBuild_FaceAreaBuilder(TopOpeBRepBuild_Area2dBuilder):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        Creates a faceareabuilder to build faces on the (wires,blocks of edge) of <ls>, using the classifier <lc>.

        Parameters
        ----------
        LS: TopOpeBRepBuild_LoopSet
        LC: TopOpeBRepBuild_LoopClassifier
        ForceClass: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_FaceAreaBuilder_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_FaceAreaBuilder(*args))

    def InitFaceAreaBuilder(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        LS: TopOpeBRepBuild_LoopSet
        LC: TopOpeBRepBuild_LoopClassifier
        ForceClass: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_FaceAreaBuilder_InitFaceAreaBuilder(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_FaceAreaBuilder

# Register TopOpeBRepBuild_FaceAreaBuilder in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_FaceAreaBuilder_swigregister(TopOpeBRepBuild_FaceAreaBuilder)

class TopOpeBRepBuild_ShellFaceClassifier(TopOpeBRepBuild_CompositeClassifier):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a classifier in 3d space, to compare : a face with a set of faces a shell with a set of faces a shell with a shell.

        Parameters
        ----------
        BB: TopOpeBRepBuild_BlockBuilder

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_ShellFaceClassifier_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_ShellFaceClassifier(*args))

    def Clear(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_ShellFaceClassifier_Clear(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_ShellFaceClassifier

# Register TopOpeBRepBuild_ShellFaceClassifier in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_ShellFaceClassifier_swigregister(TopOpeBRepBuild_ShellFaceClassifier)

class TopOpeBRepBuild_SolidAreaBuilder(TopOpeBRepBuild_Area3dBuilder):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        Creates a solidareabuilder to build solids on the (shells,blocks of face) of <ls>, using the classifier <lc>.

        Parameters
        ----------
        LS: TopOpeBRepBuild_LoopSet
        LC: TopOpeBRepBuild_LoopClassifier
        ForceClass: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_SolidAreaBuilder_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_SolidAreaBuilder(*args))

    def InitSolidAreaBuilder(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        LS: TopOpeBRepBuild_LoopSet
        LC: TopOpeBRepBuild_LoopClassifier
        ForceClass: bool,optional
        	default value is Standard_False

        Returns
        -------
        None

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_SolidAreaBuilder_InitSolidAreaBuilder(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_SolidAreaBuilder

# Register TopOpeBRepBuild_SolidAreaBuilder in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_SolidAreaBuilder_swigregister(TopOpeBRepBuild_SolidAreaBuilder)

class TopOpeBRepBuild_WireEdgeClassifier(TopOpeBRepBuild_CompositeClassifier):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a classifier on edge <f>. used to compare edges and wires on the edge <f>.

        Parameters
        ----------
        F: TopoDS_Shape
        BB: TopOpeBRepBuild_BlockBuilder

        Returns
        -------
        None

        """
        _TopOpeBRepBuild.TopOpeBRepBuild_WireEdgeClassifier_swiginit(self, _TopOpeBRepBuild.new_TopOpeBRepBuild_WireEdgeClassifier(*args))

    def LoopToShape(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        L: TopOpeBRepBuild_Loop

        Returns
        -------
        TopoDS_Shape

        """
        return _TopOpeBRepBuild.TopOpeBRepBuild_WireEdgeClassifier_LoopToShape(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepBuild.delete_TopOpeBRepBuild_WireEdgeClassifier

# Register TopOpeBRepBuild_WireEdgeClassifier in _TopOpeBRepBuild:
_TopOpeBRepBuild.TopOpeBRepBuild_WireEdgeClassifier_swigregister(TopOpeBRepBuild_WireEdgeClassifier)





